@@ -54,9 +54,7 @@ static int *compnt_map;        /* map data base component codes to internal */
 /*
  * opendb - open data base and do other house keeping.
  */
-int db_open(s, lrgintflg)
-char *s;
-char **lrgintflg;
+int db_open(char *s, char **lrgintflg)
    {
    char *msg_buf;
    char *id;
@@ -185,8 +183,7 @@ char *db_string()
  * db_impl - read basic header information for an operation into a structure
  *   and return it.
  */
-struct implement *db_impl(oper_typ)
-int oper_typ;
+struct implement *db_impl(int oper_typ)
    {
    register struct implement *ip;
    register int c;
@@ -340,8 +337,7 @@ int oper_typ;
 /*
  * db_code - read the RTL code for the body of an operation.
  */
-void db_code(ip)
-struct implement *ip;
+void db_code(struct implement *ip)
    {
    register int c;
    char *s;
@@ -850,9 +846,7 @@ static int db_rtflg()
 /*
  * db_case - get the cases for a type_case statement from the data base.
  */
-static void db_case(il, num_cases)
-struct il_code *il;
-int num_cases;
+static void db_case(struct il_code *il, int num_cases)
    {
    register int c;
    int *typ_vect;
@@ -1066,9 +1060,6 @@ static struct il_c *db_ilc()
                            case 'g':
                               db_chstr("$cg", "oto");
                               *nxtp = new_ilc(ILC_CGto);
-#ifdef MultiThread
-   #undef code
-#endif					/* MultiThead */
                               (*nxtp)->code[0] = db_ilc();
                               c = getc(db);
                               SkipWhSp(c);
@@ -1233,8 +1224,7 @@ static struct il_c *db_ilc()
  * quoted - get the string for a quoted literal. The first quote mark
  *  has been read.
  */
-static void quoted(delim)
-int delim;
+static void quoted(int delim)
    {
    register int c;
 
@@ -1258,8 +1248,7 @@ int delim;
 /*
  * db_ilcret - get the in-line C code on a return or suspend statement.
  */
-static struct il_c *db_ilcret(il_c_type)
-int il_c_type;
+static struct il_c *db_ilcret(int il_c_type)
    {
    struct il_c *ilc;
    int c;
@@ -1379,8 +1368,7 @@ static int db_icntyp()
 /*
  * new_ilc - allocate a new structure to hold a piece of in-line C code.
  */
-static struct il_c *new_ilc(il_c_type)
-int il_c_type;
+static struct il_c *new_ilc(int il_c_type)
    {
    struct il_c *ilc;
    int i;
@@ -1399,9 +1387,7 @@ int il_c_type;
  * new_il - allocate a new structure with "size" fields to hold a piece of
  *   RTL code.
  */
-struct il_code *new_il(il_type, size)
-int il_type;
-int size;
+struct il_code *new_il(int il_type, int size)
    {
    struct il_code *il;
 
@@ -1414,8 +1400,7 @@ int size;
  * db_dscrd - discard an implementation up to $end, skipping the in-line
  *   RTL code.
  */
-void db_dscrd(ip)
-struct implement *ip;
+void db_dscrd(struct implement *ip)
    {
    char state;  /* how far along we are at recognizing $end */
 
@@ -1456,9 +1441,7 @@ struct implement *ip;
  * db_chstr - we are expecting a specific string. We may already have
  *   read a prefix of it.
  */
-void db_chstr(prefix, suffix)
-char *prefix;
-char *suffix;
+void db_chstr(char *prefix, char *suffix)
    {
    int c;
 
@@ -1483,9 +1466,7 @@ char *suffix;
  * db_tbl - fill in a hash table of implementation information for the
  *  given section.
  */
-int db_tbl(section, tbl)
-char *section;
-struct implement **tbl;
+int db_tbl(char *section, struct implement **tbl)
    {
    struct implement *ip;
    int num_added = 0;
@@ -1521,9 +1502,7 @@ struct implement **tbl;
  * db_ilkup - look up id in a table of implementation information and return
  *  pointer it or NULL if it is not there.
  */
-struct implement *db_ilkup(id, tbl)
-char *id;
-struct implement **tbl;
+struct implement *db_ilkup(char *id, struct implement **tbl)
    {
    register struct implement *ptr;
 
@@ -1538,10 +1517,7 @@ struct implement **tbl;
  *   the range 0-9 and a-z, at least one of which is a digit.
  *
  */
-void nxt_pre(pre, nxt, n)
-char *pre;
-char *nxt;
-int n;
+void nxt_pre(char *pre, char *nxt, int n)
    {
    int i, num_dig;
 
@@ -1604,9 +1580,7 @@ int n;
 /*
  * cmp_pre - lexically compare 2-character prefixes.
  */
-int cmp_pre(pre1, pre2)
-char *pre1;
-char *pre2;
+int cmp_pre(char *pre1, char *pre2)
    {
    int cmp;
 
@@ -1620,9 +1594,7 @@ char *pre2;
 /*
  * cmp_1_pre - lexically compare 1 character of a prefix.
  */
-static int cmp_1_pre(p1, p2)
-int p1;
-int p2;
+static int cmp_1_pre(int p1, int p2)
    {
    if (isdigit(p1)) {
       if (isdigit(p2))
@@ -1641,9 +1613,7 @@ int p2;
 /*
  * db_err1 - print a data base error message in the form of 1 string.
  */
-void db_err1(fatal, s)
-int fatal;
-char *s;
+void db_err1(int fatal, char *s)
    {
    if (fatal)
       fprintf(stderr, "error, ");
@@ -1657,10 +1627,7 @@ char *s;
 /*
  * db_err2 - print a data base error message in the form of 2 strings.
  */
-void db_err2(fatal, s1, s2)
-int fatal;
-char *s1;
-char *s2;
+void db_err2(int fatal, char *s1, char *s2)
    {
    if (fatal)
       fprintf(stderr, "error, ");
@@ -1675,11 +1642,7 @@ char *s2;
 /*
  * db_err3 - print a data base error message in the form of 3 strings.
  */
-static void db_err3(fatal, s1, s2, s3)
-int fatal;
-char *s1;
-char *s2;
-char *s3;
+static void db_err3(int fatal, char *s1, char *s2, char *s3)
    {
    if (fatal)
       fprintf(stderr, "error, ");
