@@ -8,7 +8,7 @@
 void		EVInit		(void);
 int		activate	(dptr val, struct b_coexpr *ncp, dptr result);
 word		add		(word a,word b);
-void		addmem 	(struct b_set *ps,struct b_selem *pe, union block **pl);
+void		addmem (struct b_set *ps, struct b_selem *pe, union block **pl);
 struct astkblk	*alcactiv	(void);
 struct b_cset	*alccset	(void);
 struct b_file	*alcfile	(FILE *fd,int status,dptr name);
@@ -42,10 +42,12 @@ int		co_chng		(struct b_coexpr *ncp, struct descrip *valloc,
 				   struct descrip *rsltloc,
 				   int swtch_typ, int first);
 void		co_init		(struct b_coexpr *sblkp);
+void		coclean		(word *old);
 void		coacttrace	(struct b_coexpr *ccp,struct b_coexpr *ncp);
 void		cofailtrace	(struct b_coexpr *ccp,struct b_coexpr *ncp);
 void		corettrace	(struct b_coexpr *ccp,struct b_coexpr *ncp);
-int		coswitch	(word *old, word *new, int first);
+int		coswitch	(word *oldctx, word *newctx, int firsttime);
+void		countline	(word *ipc);
 int		cplist		(dptr dp1,dptr dp2,word i,word j);
 int		cpset		(dptr dp1,dptr dp2,word size);
 void		cpslots		(dptr dp1,dptr slotptr,word i, word j);
@@ -73,7 +75,6 @@ void		drunerr		(int n, double v);
 void		dumpact		(struct b_coexpr *ce);
 void		env_int	(char *name,word *variable,int non_neg, uword limit);
 int		equiv		(dptr dp1,dptr dp2);
-int		err		(void);
 void		err_msg		(int n, dptr v);
 void		error		(char *s1, char *s2);
 void		fatalerr	(int n,dptr v);
@@ -82,7 +83,8 @@ char		*findfile	(word *ipc);
 int		findipc		(int line);
 int		findline	(word *ipc);
 int		findloc		(word *ipc);
-void		fpetrap		(void);
+void		fpetrap		(int);
+void		genprofile	(void);
 int		getvar		(char *s,dptr vp);
 uword		hash		(dptr dp);
 union block	**hchain	(union block *pb,uword hn);
@@ -91,9 +93,9 @@ union block	*hgnext		(union block*b,struct hgstate*s,union block *e);
 union block	*hmake		(int tcode,word nslots,word nelem);
 void		icon_init	(char *name, int *argcp, char *argv[]);
 void		iconhost	(char *hostname);
-int		idelay		(int n); 
+int		idelay		(int n);
+void		initprofile	(void);
 int		interp		(int fsig,dptr cargp);
-void		inttrap		(void);
 void		irunerr		(int n, C_integer v);
 int		lexcmp		(dptr dp1,dptr dp2);
 word		longread	(char *s,int width,long len,FILE *fname);
@@ -113,100 +115,49 @@ int		putstr		(FILE *f,dptr d);
 char		*qsearch	(char *key, char *base, int nel, int width,
 				   int (*cmp)());
 int		qtos		(dptr dp,char *sbuf);
-int    		 radix		(int sign, register int r, register char *s,
+void		quittrap	(int);
+int		 radix		(int sign, register int r, register char *s,
 				   register char *end_s, union numeric *result);
 char		*reserve	(int region, word nbytes);
-void		retderef		(dptr valp, word *low, word *high);
-void		segvtrap	(void);
+void		resolve		(void);
+void		retderef	(dptr valp, word *low, word *high);
+void		segvtrap	(int);
 void		stkdump		(int);
 word		sub		(word a,word b);
 void		syserr		(char *s);
 struct b_coexpr	*topact		(struct b_coexpr *ce);
 void		xmfree		(void);
 
-#ifdef MultiThread
-   void	resolve			(struct progstate *pstate);
-   struct b_coexpr *loadicode (char *name, struct b_file *theInput,
-      struct b_file *theOutput, struct b_file *theError,
-      C_integer bs, C_integer ss, C_integer stk);
-   void actparent (int eventcode);
-   int mt_activate   (dptr tvalp, dptr rslt, struct b_coexpr *ncp);
-#else					/* MultiThread */
-   void	resolve			(void);
-#endif					/* MultiThread */
-
-#ifdef EventMon
-   void EVAsgn	(dptr dx);
-#endif					/* EventMon */
-
-#ifdef ExternalFunctions
-   dptr	extcall			(dptr x, int nargs, int *signal);
-#endif					/* ExternalFunctions */
-
-#ifdef LargeInts
-   struct b_bignum *alcbignum	(word n);
-   word		bigradix	(int sign, int r, char *s, char *x,
+/*
+ * for large integers
+ */
+struct b_bignum *alcbignum	(word n);
+word		bigradix	(int sign, int r, char *s, char *x,
 						   union numeric *result);
-   double	bigtoreal	(dptr da);
-   int		realtobig	(dptr da, dptr dx);
-   int		bigtos		(dptr da, dptr dx);
-   void		bigprint	(FILE *f, dptr da);
-   int		cpbignum	(dptr da, dptr db);
-   int		bigadd		(dptr da, dptr db, dptr dx);
-   int		bigsub		(dptr da, dptr db, dptr dx);
-   int		bigmul		(dptr da, dptr db, dptr dx);
-   int		bigdiv		(dptr da, dptr db, dptr dx);
-   int		bigmod		(dptr da, dptr db, dptr dx);
-   int		bigneg		(dptr da, dptr dx);
-   int		bigpow		(dptr da, dptr db, dptr dx);
-   int		bigpowri        (double a, dptr db, dptr drslt);
-   int		bigand		(dptr da, dptr db, dptr dx);
-   int		bigor		(dptr da, dptr db, dptr dx);
-   int		bigxor		(dptr da, dptr db, dptr dx);
-   int		bigshift	(dptr da, dptr db, dptr dx);
-   word		bigcmp		(dptr da, dptr db);
-   int		bigrand		(dptr da, dptr dx);
-#endif					/* LargeInts */
-
-
-
-#if !HIGHC_386
-   int dup2(int h1, int h2);
-#endif					/* !HIGHC_386 */
-
-#if ATARI_ST
-   char	*sbrk(int incr);
-#endif                                  /* ATARI_ST */
-
-#if HIGHC_386
-   int	brk(char *p);
-#endif					/* HIGHC_386 */
-
-#if MACINTOSH
-   #if MPW
-      char *brk(char *addr);
-      char *sbrk(int incr);
-   #endif				/* MPW */
-#endif					/* MACINTOSH */
-
-#if MVS || VM
-   #if SASC
-      #define brk(x) sbrk(((char *)(x))-sbrk(0))
-      char *sbrk(int incr);
-   #endif				/* SASC */
-#endif                                  /* MVS || VM */
-
-#ifdef MSWindows
-   #ifdef FAttrib
-      #if MSDOS
-         char *make_mode(unsigned short st_mode);
-         int strcasecmp(char *s1, char *s2);
-         int strncasecmp(char *s1, char *s2, int n);
-      #endif				/* MSDOS */
-   #endif				/* FAttrib */
-#endif					/* MSWindows */
-
+int		bigtoreal	(dptr da, double *result);
+int		realtobig	(dptr da, dptr dx);
+int     	doubletobig	(double x, dptr dx);
+int		bigtos		(dptr da, dptr dx);
+void		bigprint	(FILE *f, dptr da);
+int		cpbignum	(dptr da, dptr db);
+int		bigadd		(dptr da, dptr db, dptr dx);
+int		bigsub		(dptr da, dptr db, dptr dx);
+int		bigmul		(dptr da, dptr db, dptr dx);
+int		bigdiv		(dptr da, dptr db, dptr dx);
+int		bigmod		(dptr da, dptr db, dptr dx);
+int		bigneg		(dptr da, dptr dx);
+int		bigpow		(dptr da, dptr db, dptr dx);
+int		bigpowri        (double a, dptr db, dptr drslt);
+int		bigand		(dptr da, dptr db, dptr dx);
+int		bigor		(dptr da, dptr db, dptr dx);
+int		bigxor		(dptr da, dptr db, dptr dx);
+int		bigshift	(dptr da, dptr db, dptr dx);
+word		bigcmp		(dptr da, dptr db);
+int		bigrand		(dptr da, dptr dx);
 
+#ifdef FAttrib
+   char *make_mode(mode_t st_mode);
+#endif					/* FAttrib */
 
 #ifdef Graphics
    /*
@@ -232,7 +183,7 @@ void		xmfree		(void);
    void	qevent		(wsp ws, dptr e, int x, int y, uword t, long f);
    int	readGIF		(char *fname, int p, struct imgdata *d);
    int	rectargs	(wbp w, int argc, dptr argv, int i,
-   			   word *px, word *py, word *pw, word *ph);
+			   word *px, word *py, word *pw, word *ph);
    char	*rgbkey		(int p, double r, double g, double b);
    int	setsize		(wbp w, char *s);
    char	*si_i2s		(siptr sip, int i);
@@ -247,9 +198,9 @@ void		xmfree		(void);
    int	wlongread	(char *s, int elsize, int nelem, FILE *f);
    void	wputstr		(wbp w, char *s, int len);
    int	writeGIF	(wbp w, char *filename,
-   			  int x, int y, int width, int height);
+			  int x, int y, int width, int height);
    int	xyrowcol	(dptr dx);
-   
+
    /*
     * graphics implementation routines supplied for each platform
     * (excluding those defined as macros for X-windows)
@@ -258,7 +209,8 @@ void		xmfree		(void);
    int	SetPatternBits	(wbp w, int width, C_integer *bits, int nbits);
    int	allowresize	(wbp w, int on);
    int	blimage		(wbp w, int x, int y, int wd, int h,
-   			  int ch, unsigned char *s, word len);
+			  int ch, unsigned char *s, word len);
+   int	capture		(wbp w, int x, int y, int width, int hgt, short *data);
    wcp	clone_context	(wbp w);
    int	copyArea	(wbp w,wbp w2,int x,int y,int wd,int h,int x2,int y2);
    int	do_config	(wbp w, int status);
@@ -281,8 +233,6 @@ void		xmfree		(void);
    void	getfntnam	(wbp w, char *answer);
    void	geticonic	(wbp w, char *answer);
    int	geticonpos	(wbp w, char *s);
-   int	getimstr	(wbp w, int x, int y, int width, int hgt,
-   			  struct palentry *ptbl, unsigned char *data);
    void	getlinestyle	(wbp w, char *answer);
    int	getpixel_init	(wbp w, struct imgmem *imem);
    int	getpixel_term	(wbp w, struct imgmem *imem);
@@ -295,13 +245,10 @@ void		xmfree		(void);
    int	lowerWindow	(wbp w);
    int	mutable_color	(wbp w, dptr argv, int ac, int *retval);
    int	nativecolor	(wbp w, char *s, long *r, long *g, long *b);
-   
-   #ifndef PresentationManager
-      /* Exclude those functions defined as macros */
-      int pollevent	(void);
-      void wflush	(wbp w);
-   #endif				/* PresentationManager */
-   
+
+   int pollevent	(void);
+   void wflush		(wbp w);
+
    int	query_pointer	(wbp w, XPoint *pp);
    int	query_rootpointer (XPoint *pp);
    int	raiseWindow	(wbp w);
@@ -341,75 +288,28 @@ void		xmfree		(void);
    int	wgetq		(wbp w, dptr res);
    FILE	*wopen		(char *nm, struct b_list *hp, dptr attr, int n, int *e);
    int	wputc		(int ci, wbp w);
+   #ifndef wsync
    void	wsync		(wbp w);
+   #endif				/* wsync */
    void	xdis		(wbp w, char *s, int n);
-   
-   #ifdef ConsoleWindow
-      FILE* OpenConsole		(void);
-      int   Consolefprintf	(FILE *file, char *format, ...);
-      int   Consoleputc		(int c, FILE *file);
-      int   Consolefflush	(FILE *file);
-   #endif				/* ConsoleWindow */
-   
-   #ifdef MacGraph
-      /*
-       * Implementation routines specific to Macintosh
-       */
-      void hidecrsr (wsp ws);
-      void showcrsr (wsp ws);
-      void UpdateCursorPos(wsp ws, wcp wc);
-      void GetEvents (void);
-      void DoEvent (EventRecord *eventPtr);
-      void DoMouseUp (EventRecord *eventPtr);
-      void DoMouseDown (EventRecord *eventPtr);
-      void DoGrowWindow (EventRecord *eventPtr, WindowPtr whichWindow);
-      void GetLocUpdateRgn (WindowPtr whichWindow, RgnHandle localRgn);
-      void DoKey (EventRecord *eventPtr, WindowPtr whichWindow);
-      void EventLoop(void);
-      void HandleMenuChoice (long menuChoice);
-      void HandleAppleChoice (short item);
-      void HandleFileChoice (short item);
-      void HandleOptionsChoice (short item);
-      void DoUpdate (EventRecord *eventPtr);
-      void DoActivate (WindowPtr whichWindow, Boolean becomingActive);
-      void RedrawWindow (WindowPtr whichWindow);
-      const int ParseCmdLineStr (char *s, char *t, char **argv);
-      pascal OSErr SetDialogDefaultItem (DialogPtr theDialog, short newItem) =
-         { 0x303C, 0x0304, 0xAA68 };
-      pascal OSErr SetDialogCancelItem (DialogPtr theDialog, short newItem) =
-         { 0x303C, 0x0305, 0xAA68 };
-      pascal OSErr SetDialogTracksCursor (DialogPtr theDialog, Boolean tracks) =
-         { 0x303C, 0x0306, 0xAA68 };
-      
-      void drawarcs(wbinding *wb, XArc *arcs, int narcs);
-      void drawlines(wbinding *wb, XPoint *points, int npoints);  
-      void drawpoints(wbinding *wb, XPoint *points, int npoints);  
-      void drawrectangles(wbp wb, XRectangle *recs, int nrecs);
-      void drawsegments(wbinding *wb, XSegment *segs, int nsegs);
-      void fillarcs(wbp wb, XArc *arcs, int narcs);
-      void fillpolygon(wbp wb, XPoint *pts, int npts);  
-   #endif				/* MacGraph */
-   
+
    #ifdef XWindows
       /*
        * Implementation routines specific to X-Windows
        */
       void	unsetclip		(wbp w);
-      void	moveWindow		(wbp w, int x, int y);
       int	moveResizeWindow	(wbp w, int x, int y, int wd, int h);
       int	resetfg			(wbp w);
       int	setfgrgb		(wbp w, int r, int g, int b);
       int	setbgrgb		(wbp w, int r, int g, int b);
-      
+
       XColor	xcolor			(wbp w, LinearColor clr);
       LinearColor	lcolor		(wbp w, XColor color);
       int	pixmap_open		(wbp w, dptr attribs, int argc);
       int	pixmap_init		(wbp w);
       int	remap			(wbp w, int x, int y);
       int	seticonimage		(wbp w, dptr dp);
-      void	makeIcon		(wbp w, int x, int y);
       int	translate_key_event	(XKeyEvent *k1, char *s, KeySym *k2);
-      int	handle_misc		(wdp display, wbp w);
       wdp	alc_display		(char *s);
       void	free_display		(wdp wd);
       wfp	alc_font		(wbp w, char **s);
@@ -426,8 +326,8 @@ void		xmfree		(void);
       int	resizePixmap		(wbp w, int width, int height);
       void	wflushall		(void);
    #endif				/* XWindows */
-   
-   #ifdef MSWindows
+
+   #ifdef WinGraphics
       /*
        * Implementation routines specific to MS Windows
        */
@@ -446,7 +346,7 @@ void		xmfree		(void);
       HDC CreateWinDC		(wbp);
       HDC CreatePixDC		(wbp, HDC);
       HBITMAP loadimage	(wbp wb, char *filename, unsigned int *width,
-      			unsigned int *height, int atorigin, int *status);
+			unsigned int *height, int atorigin, int *status);
       void wfreersc();
       int getdepth(wbp w);
       HBITMAP CreateBitmapFromData(char *data);
@@ -463,81 +363,20 @@ void		xmfree		(void);
       void drawsegments(wbinding *wb, XSegment *segs, int nsegs);
       void drawstrng(wbinding *wb, int x, int y, char *s, int slen);
       void unsetclip(wbp w);
-      
-   #endif				/* MSWindows */
-   
-   #ifdef PresentationManager
-      /*
-       * Implementation routines specific to OS/2 Presentation Manager
-       */
-      wsp ObtainEvents(wsp ws, SHORT blockflag, ULONG messg, QMSG *msg);
-      void InterpThreadStartup(void *args);
-      void InterpThreadShutdown(void);
-      void DestroyWindow(wsp ws);
-      void LoadDefAttrs(wbinding *wb, wsp ws, wcp wc);
-      void ResizeBackingBitmap(wsp ws, SHORT x, SHORT y);
-      int  moveResizeWindow(wbp w,int x, int y, int width, int height);
-      void moveWindow(wbp w, int x, int y);
-      int  resizeWindow(wbp w,int width,int height);
-      int SetNewBitPattern(wcp wc, PBYTE bits);
-      int LoadFont(wbp wb, char *family, LONG attr, ULONG fontsize);
-      void FreeIdTable(void);
-      void FreeLocalID(LONG id);
-      
-      /* -- not needed because of macro definitions
-      void SetCharContext(wbp wb, wsp ws, wcp wc);
-      void SetAreaContext(wbp wb, wsp ws, wcp wc);
-      void SetLineContext(wbp wb, wsp ws, wcp wc);
-      void SetImageContext(wbp wb, wsp ws, wcp wc);
-         -- */
-      
-      void SetClipContext(wbp wb, wsp ws, wcp wc);
-      void UnsetContext(wcp wc, void (*f)(wcp, wsp));
-      void UCharContext(wcp wc, wsp ws);
-      void ULineContext(wcp wc, wsp ws);
-      void UAreaContext(wcp wc, wsp ws);
-      void UImageContext(wcp wc, wsp ws);
-      void UClipContext(wcp wc, wsp ws);
-      void UAllContext(wcp wc, wsp ws);
-      void drawpoints(wbp wb, XPoint *pts, int npts);
-      void drawsegments(wbp wb, XSegment *segs, int nsegs);
-      void drawstrng(wbp wb, int x, int y, char *str, int slen);
-      void drawarcs(wbp w, XArc *arcs, int narcs);
-      void drawlines(wbp wb, XPoint *pts, int npts);
-      void drawrectangles(wbp wb, XRectangle *recs, int nrecs);
-      int dumpimage(wbp wb, char *filename, int x, int y, int width, int height);
-      void fillpolygon(wbp wb, XPoint *pts, int npts);
-      HBITMAP loadimage(wbp wb, char *filename, int *width, int *height);
-      void InitializeIdTable(void);
-      void InitializeColorTable(void);
-      void FreeColorTable(void);
-      LONG GetColorIndex(char *buf, double gamma);
-      void AddLocalIdToWindow(wsp ws, LONG id);
-      void ReleaseLocalId(LONG id);
-      void ReleaseColor(LONG indx);
-      void ColorInitPS(wbp wb);
-      void GetColorName(LONG indx, char *buf, int len);
-      void EnsureColorAvailable(LONG indx);
-      int GetTextWidth(wbp wb, char *text, int len);
-      int AddWindowDep(wsp ws, wcp wc);
-      int AddContextDep(wsp ws, wcp wc);
-      FILE *PMOpenConsole(void);
-      void UpdateCursorConfig(wsp ws, wcp wc);
-      void UpdateCursorPos(wsp ws, wcp wc);
-      
-   #endif				/* PresentationManager */
-   
-#endif					/* Graphics */
 
+   #endif				/* WinGraphics */
+
+#endif					/* Graphics */
 
 /*
  * Prototypes for the run-time system.
  */
 
-struct b_external *alcextrnl	(int n);
+struct b_external *alcexternal	(long nbytes, struct b_extlfuns *f, void *data);
 struct b_record *alcrecd	(int nflds,union block *recptr);
 struct b_tvsubs *alcsubs	(word len,word pos,dptr var);
 int	bfunc		(void);
+struct descrip callextfunc (int (*)(int, dptr), dptr, dptr);
 long	ckadd		(long i, long j);
 long	ckmul		(long i, long j);
 long	cksub		(long i, long j);
@@ -550,9 +389,12 @@ int	cvcset		(dptr dp,int * *cs,int *csbuf);
 int	cvnum		(dptr dp,union numeric *result);
 int	cvreal		(dptr dp,double *r);
 void	deref		(dptr dp1, dptr dp2);
+int	extlcmp		(int argc, dptr argv);
+int	extlcopy	(int argc, dptr argv);
+int	extlimage	(int argc, dptr argv);
+int	extlname	(int argc, dptr argv);
 void	envset		(void);
 int	eq		(dptr dp1,dptr dp2);
-int	fixtrap		(void);
 int	get_name	(dptr dp1, dptr dp2);
 int	getch		(void);
 int	getche		(void);
@@ -582,50 +424,25 @@ int	tvcmp4		(struct dpair *dp1,struct dpair *dp2);
 int	tvtbl_asgn	(dptr dest, const dptr src);
 void	varargs		(dptr argp, int nargs, dptr rslt);
 
-#ifdef MultiThread
-   struct b_coexpr *alccoexp (long icodesize, long stacksize);
-#else					/* MultiThread */
-   struct b_coexpr *alccoexp (void);
-#endif					/* MultiThread */
+struct b_coexpr *alccoexp (void);
 
-#if COMPILER
+struct b_refresh *alcrefresh	(word *e, int nl, int nt);
+void	atrace			(dptr dp);
+void	ctrace			(dptr dp, int nargs, dptr arg);
+void	failtrace		(dptr dp);
+int	invoke			(int nargs, dptr *cargs, int *n);
+void	rtrace			(dptr dp, dptr rval);
+void	strace			(dptr dp, dptr rval);
+void	tracebk			(struct pf_marker *lcl_pfp, dptr argp);
+int	xdisp			(struct pf_marker *fp, dptr dp, int n, FILE *f);
 
-   struct b_refresh *alcrefresh	(int na, int nl, int nt, int wk_sz);
-   void	atrace			(void);
-   void	ctrace			(void);
-   void	failtrace		(void);
-   void	initalloc		(void);
-   int	invoke			(int n, dptr args, dptr rslt, continuation c);
-   void	rtrace			(void);
-   void	strace			(void);
-   void	tracebk			(struct p_frame *lcl_pfp, dptr argp);
-   int	xdisp			(struct p_frame *fp, dptr dp, int n, FILE *f);
+#define Fargs dptr cargp
+int	Obscan			(int nargs, Fargs);
+int	Ocreate			(word *entryp, Fargs);
+int	Oescan			(int nargs, Fargs);
+int	Ofield			(int nargs, Fargs);
+int	Olimit			(int nargs, Fargs);
+int	Ollist			(int nargs, Fargs);
+int	Omkrec			(int nargs, Fargs);
 
-#else					/* COMPILER */
-   
-   struct b_refresh *alcrefresh	(word *e, int nl, int nt);
-   void	atrace			(dptr dp);
-   void	ctrace			(dptr dp, int nargs, dptr arg);
-   void	failtrace		(dptr dp);
-   int	invoke			(int nargs, dptr *cargs, int *n);
-   void	rtrace			(dptr dp, dptr rval);
-   void	strace			(dptr dp, dptr rval);
-   void	tracebk			(struct pf_marker *lcl_pfp, dptr argp);
-   int	xdisp			(struct pf_marker *fp, dptr dp, int n, FILE *f);
-   
-   #define Fargs dptr cargp
-   int	Obscan			(int nargs, Fargs);
-   int	Ocreate			(word *entryp, Fargs);
-   int	Oescan			(int nargs, Fargs);
-   int	Ofield			(int nargs, Fargs);
-   int	Olimit			(int nargs, Fargs);
-   int	Ollist			(int nargs, Fargs);
-   int	Omkrec			(int nargs, Fargs);
-
-   #ifdef MultiThread
-      void	initalloc	(word codesize, struct progstate *p);
-   #else				/* MultiThread */
-      void	initalloc	(word codesize);
-   #endif				/* MultiThread */
-   
-#endif					/* COMPILER */
+void	initalloc		(word codesize);
