@@ -25,13 +25,6 @@ static struct	tgentry *glookup	(char *id);
 static struct	tlentry *llookup	(char *id);
 static void	putglob
    (char *id,int id_type, int n_args);
-
-#ifdef DeBugTrans
-   void	cdump	(void);
-   void	gdump	(void);
-   void	ldump	(void);
-#endif					/* DeBugTrans */
-
 
 /*
  * Keyword table.
@@ -42,16 +35,15 @@ struct keyent {
    int keyid;
    };
 
-#define KDef(p,n) Lit(p), n,
+#define KDef(p,n) { Lit(p), n },
 static struct keyent keytab[] = {
 #include "../h/kdefs.h"
-   NULL, -1
+   { NULL, -1 }
 };
 
 /*
  * loc_init - clear the local and constant symbol tables.
  */
-
 void loc_init()
    {
    struct tlentry *lptr, *lptr1;
@@ -91,9 +83,7 @@ void loc_init()
  *  the identifier if it isn't already there.  Some semantic checks
  *  are performed.
  */
-void install(name, flag, argcnt)
-char *name;
-int flag, argcnt;
+void install(char *name, int flag, int argcnt)
    {
    union {
       struct tgentry *gp;
@@ -143,9 +133,7 @@ int flag, argcnt;
  * putloc - make a local symbol table entry and return the index
  *  of the entry in lhash.  alcloc does the work if there is a collision.
  */
-int putloc(id,id_type)
-char *id;
-int id_type;
+int putloc(char *id, int id_type)
    {
    register struct tlentry *ptr;
 
@@ -161,10 +149,7 @@ int id_type;
  * putglob makes a global symbol table entry. alcglob does the work if there
  *  is a collision.
  */
-
-static void putglob(id, id_type, n_args)
-char *id;
-int id_type, n_args;
+static void putglob(char *id, int id_type, int n_args)
    {
    register struct tgentry *ptr;
 
@@ -178,9 +163,7 @@ int id_type, n_args;
  * putlit makes a constant symbol table entry and returns the table "index"
  *  of the constant.  alclit does the work if there is a collision.
  */
-int putlit(id, idtype, len)
-char *id;
-int len, idtype;
+int putlit(char *id, int idtype, int len)
    {
    register struct tcentry *ptr;
 
@@ -196,9 +179,7 @@ int len, idtype;
  * llookup looks up id in local symbol table and returns pointer to
  *  to it if found or NULL if not present.
  */
-
-static struct tlentry *llookup(id)
-char *id;
+static struct tlentry *llookup(char *id)
    {
    register struct tlentry *ptr;
 
@@ -212,8 +193,7 @@ char *id;
  * glookup looks up id in global symbol table and returns pointer to
  *  to it if found or NULL if not present.
  */
-static struct tgentry *glookup(id)
-char *id;
+static struct tgentry *glookup(char *id)
    {
    register struct tgentry *ptr;
 
@@ -228,9 +208,7 @@ char *id;
  * clookup looks up id in constant symbol table and returns pointer to
  *  to it if found or NULL if not present.
  */
-static struct tcentry *clookup(id,flag)
-char *id;
-int flag;
+static struct tcentry *clookup(char *id, int flag)
    {
    register struct tcentry *ptr;
 
@@ -245,8 +223,7 @@ int flag;
  * klookup looks up keyword named by id in keyword table and returns
  *  its number (keyid).
  */
-int klookup(id)
-register char *id;
+int klookup(char *id)
    {
    register struct keyent *kp;
 
@@ -257,87 +234,11 @@ register char *id;
    return 0;
    }
 
-#ifdef DeBugTrans
-/*
- * ldump displays local symbol table to stdout.
- */
-
-void ldump()
-   {
-   register int i;
-   register struct tlentry *lptr;
-   int n;
-
-   if (llast == NULL)
-      n = 0;
-   else
-      n = llast->l_index + 1;
-   fprintf(stderr,"Dump of local symbol table (%d entries)\n", n);
-   fprintf(stderr," loc   blink   id		  (name)      flags\n");
-   for (i = 0; i < lhsize; i++)
-      for (lptr = lhash[i]; lptr != NULL; lptr = lptr->l_blink)
-         fprintf(stderr,"%5d  %5d  %5d	%20s  %7o\n", lptr->l_index,
-		lptr->l_blink, lptr->l_name, lptr->l_name, lptr->l_flag);
-   fflush(stderr);
-
-   }
-
-/*
- * gdump displays global symbol table to stdout.
- */
-
-void gdump()
-   {
-   register int i;
-   register struct tgentry *gptr;
-   int n;
-
-   if (glast == NULL)
-      n = 0;
-   else
-      n = glast->g_index + 1;
-   fprintf(stderr,"Dump of global symbol table (%d entries)\n", n);
-   fprintf(stderr," loc   blink   id		  (name)      flags	  nargs\n");
-   for (i = 0; i < ghsize; i++)
-      for (gptr = ghash[i]; gptr != NULL; gptr = gptr->g_blink)
-         fprintf(stderr,"%5d  %5d  %5d	%20s  %7o   %8d\n", gptr->g_index,
-		gptr->g_blink, gptr->g_name, gptr->g_name,
-		gptr->g_flag, gptr->g_nargs);
-   fflush(stderr);
-   }
-
-/*
- * cdump displays constant symbol table to stdout.
- */
-
-void cdump()
-   {
-   register int i;
-   register struct tcentry *cptr;
-   int n;
-
-   if (clast == NULL)
-      n = 0;
-   else
-      n = clast->c_index + 1;
-   fprintf(stderr,"Dump of constant symbol table (%d entries)\n", n);
-   fprintf(stderr," loc   blink   id		  (name)      flags\n");
-   for (i = 0; i < lchsize; i++)
-      for (cptr = chash[i]; cptr != NULL; cptr = cptr->c_blink)
-         fprintf(stderr,"%5d  %5d  %5d	%20s  %7o\n", cptr->c_index,
-		cptr->c_blink, cptr->c_name, cptr->c_name, cptr->c_flag);
-   fflush(stderr);
-   }
-#endif					/* DeBugTrans */
-
 /*
  * alcloc allocates a local symbol table entry, fills in fields with
  *  specified values and returns the new entry.
  */
-static struct tlentry *alcloc(blink, name, flag)
-struct tlentry *blink;
-char *name;
-int flag;
+static struct tlentry *alcloc(struct tlentry *blink, char *name, int flag)
    {
    register struct tlentry *lp;
 
@@ -362,10 +263,8 @@ int flag;
  * alcglob allocates a global symbol table entry, fills in fields with
  *  specified values and returns offset of new entry.
  */
-static struct tgentry *alcglob(blink, name, flag, nargs)
-struct tgentry *blink;
-char *name;
-int flag, nargs;
+static struct tgentry *alcglob(struct tgentry *blink,
+   char *name, int flag, int nargs)
    {
    register struct tgentry *gp;
 
@@ -391,10 +290,8 @@ int flag, nargs;
  * alclit allocates a constant symbol table entry, fills in fields with
  *  specified values and returns the new entry.
  */
-static struct tcentry *alclit(blink, name, len, flag)
-struct tcentry *blink;
-char *name;
-int len, flag;
+static struct tcentry *alclit(struct tcentry *blink,
+   char *name, int len, int flag)
    {
    register struct tcentry *cp;
 
@@ -419,8 +316,7 @@ int len, flag;
 /*
  * lout dumps local symbol table to fd, which is a .u1 file.
  */
-void lout(fd)
-FILE *fd;
+void lout(FILE *fd)
    {
    register struct tlentry *lp;
 
@@ -432,8 +328,7 @@ FILE *fd;
 /*
  * constout dumps constant symbol table to fd, which is a .u1 file.
  */
-void constout(fd)
-FILE *fd;
+void constout(FILE *fd)
    {
    register int l;
    register char *c;
@@ -459,9 +354,7 @@ FILE *fd;
 /*
  * rout dumps a record declaration for name to file fd, which is a .u2 file.
  */
-void rout(fd,name)
-FILE *fd;
-char *name;
+void rout(FILE *fd, char *name)
    {
    register struct tlentry *lp;
    int n;
@@ -480,8 +373,7 @@ char *name;
  *  include: implicit status, tracing activation, link directives,
  *  invocable directives, and the global table.
  */
-void gout(fd)
-FILE *fd;
+void gout(FILE *fd)
    {
    register char *name;
    register struct tgentry *gp;
