@@ -83,8 +83,7 @@ void init_tok()
 /*
  * pp_tok_id - see if s in the name of a preprocessing directive.
  */
-static int pp_tok_id(s)
-char *s;
+static int pp_tok_id(char *s)
    {
    struct rsrvd_wrd *rw;
 
@@ -112,8 +111,7 @@ int chk_eq_sign()
  *  and return it, otherwise return NULL. This function also helps keeps track
  *  of preprocessor directive boundaries.
  */
-static struct token *chck_wh_sp(cs)
-struct char_src *cs;
+static struct token *chck_wh_sp(struct char_src *cs)
    {
    register int c1, c2;
    struct token *t;
@@ -212,7 +210,7 @@ struct char_src *cs;
    /*
     * Look ahead to see if a ## operator is next.
     */
-   if (*next_char == '#' && next_char[1] == '#')
+   if (*next_char == '#' && next_char[1] == '#') {
       if (tok_id == PpDirEnd)
          errt1(t, "## expressions must not cross directive boundaries");
       else {
@@ -222,6 +220,7 @@ struct char_src *cs;
          free_t(t);
          return NULL;
          }
+      }
    return t;
    }
 
@@ -259,9 +258,7 @@ static struct token *pp_number()
 /*
  * char_str - construct a token for a character constant or string literal.
  */
-static struct token *char_str(delim, tok_id)
-int delim;
-int tok_id;
+static struct token *char_str(int delim, int tok_id)
    {
    register int c;
 
@@ -290,10 +287,7 @@ int tok_id;
  * hdr_tok - create a token for an #include header. The delimiter may be
  *  > or ".
  */
-static struct token *hdr_tok(delim, tok_id, cs)
-int delim;
-int tok_id;
-struct char_src *cs;
+static struct token *hdr_tok(int delim, int tok_id, struct char_src *cs)
    {
    register int c;
 
@@ -365,7 +359,7 @@ struct token *tokenize()
           *  for white space to discard.
           */
          cs->dir_state = Within;
-         if ((t1 = chck_wh_sp(cs)) != NULL)
+         if ((t1 = chck_wh_sp(cs)) != NULL) {
             if (t1->tok_id == PpDirEnd) {
                /*
                 * We found a new-line, this is a null preprocessor directive.
@@ -376,6 +370,7 @@ struct token *tokenize()
                }
             else
                free_t(t1);  /* discard white space */
+	    }
          c = *next_char;
          if (islower(c) || isupper(c) || c == '_') {
             /*
@@ -399,11 +394,12 @@ struct token *tokenize()
                    * A header name has to be tokenized specially. Find
                    *  it, then save the token.
                    */
-                  if ((t2 = chck_wh_sp(cs)) != NULL)
+                  if ((t2 = chck_wh_sp(cs)) != NULL) {
                      if (t2->tok_id == PpDirEnd)
                         errt1(t2, "file name missing from #include");
                      else
                         free_t(t2);
+		  }
                   c = *next_char;
                   if (c == '"')
                      cs->tok_sav = hdr_tok('"', StrLit, cs);
@@ -752,12 +748,13 @@ struct token *tokenize()
          /*
           * The operand must be in the same preprocessing directive.
           */
-         if ((t2 = chck_wh_sp(cs)) != NULL)
+         if ((t2 = chck_wh_sp(cs)) != NULL) {
             if (t2->tok_id == PpDirEnd)
               errt2(t2, t1->image,
                " preprocessing expression must not cross directive boundary");
             else
                free_t(t2);
+	    }
          return t1;
 
       default:
