@@ -4,11 +4,7 @@
 #define IndentInc 3
 #define MaxCol 80
 
-#if (MVS || VM) && SASC
-#define Max(x,y)        __builtin_max(x,y)
-#else                                   /* SASC */
 #define Max(x,y)        ((x)>(y)?(x):(y))
-#endif                                  /* SASC */
 
 /*
  * cfile is used to create a list of cfiles created from a source file.
@@ -174,8 +170,8 @@ extern int abs_ret; /* type from abstract return statement */
 #define AbstrNd  15 /* abstract type computation */
 #define IcnTypNd 16 /* name of an Icon type */
 
-#define NewNode(size) (struct node *)alloc((unsigned int)\
-    (sizeof(struct node) + (size-1) * sizeof(union field)))
+#define NewNode(size) (struct node *)alloc(\
+    sizeof(struct node) + (size-1) * sizeof(union field))
 
 union field {
    struct node *child;
