@@ -57,8 +57,7 @@ struct implement *cur_impl;	/* data base entry for current operation */
 /*
  * loaddb - load data base.
  */
-void loaddb(dbname)
-char *dbname;
+void loaddb(char *dbname)
    {
    char *op;
    struct implement *ip;
@@ -152,9 +151,7 @@ char *dbname;
  * max_pre - find the maximum prefix in an implemetation table and set the
  *  prefix array to the next value.
  */
-static void max_pre(tbl, pre)
-struct implement **tbl;
-char *pre;
+static void max_pre(struct implement **tbl, char *pre)
    {
    register struct implement *ptr;
    unsigned hashval;
@@ -183,8 +180,7 @@ char *pre;
  * src_lkup - return pointer to dependency information for the given
  *   source file.
  */
-struct srcfile *src_lkup(srcname)
-char *srcname;
+struct srcfile *src_lkup(char *srcname)
    {
    unsigned hashval;
    struct srcfile *sfile;
@@ -216,9 +212,7 @@ char *srcname;
  * add_dpnd - add the given source/dependency relation to the dependency
  *   table.
  */
-void add_dpnd(sfile, c_name)
-struct srcfile *sfile;
-char *c_name;
+void add_dpnd(struct srcfile *sfile, char *c_name)
    {
    struct cfile *cf;
 
@@ -231,8 +225,7 @@ char *c_name;
 /*
  * clr_dpnd - delete all dependencies for the given source file.
  */
-void clr_dpnd(srcname)
-char *srcname;
+void clr_dpnd(char *srcname)
    {
    src_lkup(srcname)->dependents = NULL;
    }
@@ -240,8 +233,7 @@ char *srcname;
 /*
  * dumpdb - write the updated data base.
  */
-void dumpdb(dbname)
-char *dbname;
+void dumpdb(char *dbname)
    {
    #ifdef Rttx
       fprintf(stdout,
@@ -311,13 +303,8 @@ char *dbname;
  * prt_impl - sort and print to the data base the enties from one
  *   of the operation tables.
  */
-static void prt_impls(db, sect, tbl, num, sort_ary, cmp)
-FILE *db;
-char *sect;
-struct implement **tbl;
-int num;
-struct implement **sort_ary;
-int (*cmp)();
+static void prt_impls(FILE *db, char *sect, struct implement **tbl,
+   int num, struct implement **sort_ary, int (*cmp)())
    {
    int i;
    int j;
@@ -471,9 +458,7 @@ int (*cmp)();
  *   code used by iconc to perform type infernence for the operation
  *   and to generate a tailored version of the operation.
  */
-static void put_inlin(db, il)
-FILE *db;
-struct il_code *il;
+static void put_inlin(FILE *db, struct il_code *il)
    {
    int i;
    int num_cases;
@@ -542,7 +527,7 @@ struct il_code *il;
          fprintf(db, "%d ", num_cases);
          indx = 1;
          for (i = 0; i < num_cases; ++i) {
-            fprintf(db, "\n%d ", il->u[indx++].n);    /* selection number */
+            fprintf(db, "\n%ld ", (long)il->u[indx++].n);/* selection number */
             put_inlin(db, il->u[indx++].fld);        /* action */
             }
          fprintf(db, "\n");
@@ -567,14 +552,14 @@ struct il_code *il;
           * runerr with no value argument.
           */
          fprintf(db, "runerr1 ");
-         fprintf(db, "%d ", il->u[0].n);      /* error number */
+         fprintf(db, "%ld ", (long)il->u[0].n);      /* error number */
          break;
       case IL_Err2:
          /*
           * runerr with a value argument.
           */
          fprintf(db, "runerr2 ");
-         fprintf(db, "%d ", il->u[0].n);      /* error number */
+         fprintf(db, "%ld ", (long)il->u[0].n);      /* error number */
          put_inlin(db, il->u[1].fld);          /* variable */
          break;
       case IL_Lst:
@@ -649,15 +634,15 @@ struct il_code *il;
          /*
           * A variable.
           */
-         fprintf(db, "%d ", il->u[0].n);    /* symbol table index */
+         fprintf(db, "%ld ", (long)il->u[0].n);    /* symbol table index */
          break;
       case IL_Subscr:
          /*
           * A subscripted variable.
           */
          fprintf(db, "[ ");
-         fprintf(db, "%d ", il->u[0].n);    /* symbol table index */
-         fprintf(db, "%d ", il->u[1].n);    /* subscripting index */
+         fprintf(db, "%ld ", (long)il->u[0].n);    /* symbol table index */
+         fprintf(db, "%ld ", (long)il->u[1].n);    /* subscripting index */
          break;
       case IL_Block:
          /*
@@ -671,7 +656,7 @@ struct il_code *il;
           /*
            * Output a symbol table of tended variables.
            */
-         fprintf(db, "%d ", il->u[1].n);    /* number of local tended */
+         fprintf(db, "%ld ", (long)il->u[1].n);    /* number of local tended */
          for (i = 2; i - 2 < il->u[1].n; ++i)
              switch (il->u[i].n) {
                 case TndDesc:
@@ -733,8 +718,8 @@ struct il_code *il;
          else
             fprintf(db, "f ");
 
-         fprintf(db, "%d ", il->u[5].n);    /* num string bufs */
-         fprintf(db, "%d ", il->u[6].n);    /* num cset bufs */
+         fprintf(db, "%ld ", (long)il->u[5].n);    /* num string bufs */
+         fprintf(db, "%ld ", (long)il->u[6].n);    /* num cset bufs */
          i = il->u[7].n;
          fprintf(db, "%d ", i);             /* num args */
          indx = 8;
@@ -827,9 +812,7 @@ struct il_code *il;
 /*
  * put_case - put the cases of a type_case statement into the data base file.
  */
-static int put_case(db, il)
-FILE *db;
-struct il_code *il;
+static int put_case(FILE *db, struct il_code *il)
    {
    int *typ_vect;
    int i, j;
@@ -856,9 +839,7 @@ struct il_code *il;
  * put_typcd - convert a numeric type code into an alpha type code and
  *  put it in the data base file.
  */
-static void put_typcd(db, typcd)
-FILE *db;
-int typcd;
+static void put_typcd(FILE *db, int typcd)
    {
    if (typcd >= 0)
       fprintf(db, "T%d ", typcd);
@@ -913,9 +894,7 @@ int typcd;
 /*
  * put_ilc - put in-line C code in the data base file.
  */
-static void put_ilc(db, ilc)
-FILE *db;
-struct il_c *ilc;
+static void put_ilc(FILE *db, struct il_c *ilc)
    {
    /*
     * In-line C code is either "nil" or code bracketed by $c $e.
@@ -961,15 +940,15 @@ struct il_c *ilc;
             fprintf(db, "$efail ");  /* errorfail statement */
             break;
          case ILC_Goto:
-            fprintf(db, "$goto %d ", ilc->n);  /* goto label */
+            fprintf(db, "$goto %ld ", (long)ilc->n);  /* goto label */
             break;
          case ILC_CGto:
             fprintf(db, "$cgoto ");            /* conditional goto */
             put_ilc(db, ilc->code[0]);         /* condition (with $c $e) */
-            fprintf(db, "%d ", ilc->n);        /* label */
+            fprintf(db, "%ld ", (long)ilc->n);        /* label */
             break;
          case ILC_Lbl:
-            fprintf(db, "$lbl %d ", ilc->n);   /* label */
+            fprintf(db, "$lbl %ld ", (long)ilc->n);   /* label */
             break;
          case ILC_LBrc:
             fprintf(db, "${ ");                /* start of C block with dcls */
@@ -989,10 +968,7 @@ struct il_c *ilc;
 /*
  * put_var - output in-line C code for a variable.
  */
-static void put_var(db, code, ilc)
-FILE *db;
-int code;
-struct il_c *ilc;
+static void put_var(FILE *db, int code, struct il_c *ilc)
    {
    fprintf(db, "$%c", code);  /* 'r': non-mod ref, 'm': mod ref, 't': tended */
    if (ilc->s != NULL)
@@ -1000,17 +976,14 @@ struct il_c *ilc;
    if (ilc->n == RsltIndx)
       fprintf(db, "r ");          /* this is "result" */
    else
-      fprintf(db, "%d ", ilc->n); /* offset into a symbol table */
+      fprintf(db, "%ld ", (long)ilc->n); /* offset into a symbol table */
    }
 
 /*
  * ret_flag - put a return/suspend/fail/fall-through flag in the data base
  *  file.
  */
-static void ret_flag(db, flag, may_fthru)
-FILE *db;
-int flag;
-int may_fthru;
+static void ret_flag(FILE *db, int flag, int may_fthru)
    {
    if (flag & DoesFail)
       fprintf(db, "f");      /* can fail */
@@ -1028,20 +1001,19 @@ int may_fthru;
       fprintf(db, "e");      /* can do error conversion */
    else
       fprintf(db, "_");      /* cannot do error conversion */
-   if (may_fthru)            /* body functions only: */
+   if (may_fthru) {            /* body functions only: */
       if (flag & DoesFThru)
          fprintf(db, "t");      /* can fall through */
       else
          fprintf(db, "_");      /* cannot fall through */
+      }
   fprintf(db, " ");
   }
 
 /*
  * put_ret - put the body of a return/suspend statement in the data base.
  */
-static void put_ret(db, ilc)
-FILE *db;
-struct il_c *ilc;
+static void put_ret(FILE *db, struct il_c *ilc)
    {
    int i;
 
@@ -1062,9 +1034,7 @@ struct il_c *ilc;
  * name_cmp - compare implementation structs by name; function used as
  *  an argument to qsort().
  */
-static int name_cmp(p1, p2)
-char *p1;
-char *p2;
+static int name_cmp(char *p1, char *p2)
    {
    register struct implement *ip1;
    register struct implement *ip2;
@@ -1078,9 +1048,7 @@ char *p2;
  * op_cmp - compare implementation structs by operator and number of args;
  *   function used as an argument to qsort().
  */
-static int op_cmp(p1, p2)
-char *p1;
-char *p2;
+static int op_cmp(char *p1, char *p2)
    {
    register int cmp;
    register struct implement *ip1;
@@ -1099,8 +1067,7 @@ char *p2;
 /*
  * prt_dpnd - print dependency information to the data base.
  */
-static void prt_dpnd(db)
-FILE *db;
+static void prt_dpnd(FILE *db)
    {
    struct srcfile **sort_ary;
    struct srcfile *sfile;
@@ -1147,9 +1114,7 @@ FILE *db;
 /*
  * src_cmp - compare srcfile structs; function used as an argument to qsort().
  */
-static int src_cmp(p1, p2)
-char *p1;
-char *p2;
+static int src_cmp(char *p1, char *p2)
    {
    register struct srcfile *sp1;
    register struct srcfile *sp2;
@@ -1162,10 +1127,7 @@ char *p2;
 /*
  * prt_c_fl - print list of C files in reverse order.
  */
-static int prt_c_fl(db, clst, line_left)
-FILE *db;
-struct cfile *clst;
-int line_left;
+static int prt_c_fl(FILE *db, struct cfile *clst, int line_left)
    {
    int len;
 
@@ -1191,8 +1153,7 @@ int line_left;
  * full_lst - print a full list of all files produced by translations
  *  as represented in the dependencies section of the data base.
  */
-void full_lst(fname)
-char *fname;
+void full_lst(char *fname)
    {
    unsigned hashval;
    struct srcfile *sfile;
@@ -1220,8 +1181,7 @@ char *fname;
  * impl_fnc - find or create implementation struct for function currently
  *  being parsed.
  */
-void impl_fnc(name)
-struct token *name;
+void impl_fnc(struct token *name)
    {
    /*
     * Set the global operation type for later use. If this is a
@@ -1235,8 +1195,7 @@ struct token *name;
  * impl_key - find or create implementation struct for keyword currently
  *  being parsed.
  */
-void impl_key(name)
-struct token *name;
+void impl_key(struct token *name)
    {
    /*
     * Set the global operation type for later use. If this is a
@@ -1250,11 +1209,8 @@ struct token *name;
  * set_impl - lookup a function or keyword in a hash table and update the
  *  entry, creating the entry if needed.
  */
-static int set_impl(name, tbl, num_impl, pre)
-struct token *name;
-struct implement **tbl;
-int num_impl;
-char *pre;
+static int set_impl(struct token *name, struct implement **tbl,
+   int num_impl, char *pre)
    {
    register struct implement *ptr;
    char *name_s;
@@ -1311,8 +1267,7 @@ char *pre;
  * set_prms - set the parameter information of an implementation based on
  *   the params list constructed during parsing.
  */
-static void set_prms(ptr)
-struct implement *ptr;
+static void set_prms(struct implement *ptr)
    {
    struct sym_entry *sym;
    int nargs;
@@ -1346,9 +1301,7 @@ struct implement *ptr;
  * impl_op - find or create implementation struct for operator currently
  *  being parsed.
  */
-void impl_op(op_sym, name)
-struct token *op_sym;
-struct token *name;
+void impl_op(struct token *op_sym, struct token *name)
    {
    register struct implement *ptr;
    char *op;
@@ -1426,10 +1379,7 @@ struct token *name;
  * set_r_seq - save result sequence information for updating the
  *  operation entry.
  */
-void set_r_seq(min, max, resume)
-long min;
-long max;
-int resume;
+void set_r_seq(long min, long max, int resume)
    {
    if (min == UnbndSeq)
       min = 0;
