@@ -24,8 +24,8 @@ static char *options =
  *  interpreted as relative to where rtt.exe is or where rtt.exe is
  *  invoked.
  */
-    char *grttin_path = "../src/h/grttin.h";
-    char *rt_path = "../src/h/rt.h";
+    char *grttin_path = "../h/grttin.h";
+    char *rt_path = "../h/rt.h";
 
 /*
  *  Note: rtt presently does not process system include files. If this
@@ -39,7 +39,7 @@ char *compiler_def;
 FILE *out_file;
 char *inclname;
 int def_fnd;
-char *largeints = NULL;
+char *largeints = "LargeInts";
 
 int iconx_flg = 0;
 int enable_out = 0;
@@ -73,9 +73,7 @@ extern int optind;		/* index into parent argv vector */
 extern int optopt;		/* character checked for validity */
 extern char *optarg;		/* argument associated with option */
 
-int main(argc, argv)
-int argc;
-char **argv;
+int main(int argc, char **argv)
    {
    int c;
    int nopts;
@@ -239,18 +237,13 @@ char **argv;
 /*
  * trans - translate a source file.
  */
-void trans(src_file)
-char *src_file;
+void trans(char *src_file)
    {
    char *cname;
    char buf[MaxPath];		/* file name construction buffer */
    char *buf_ptr;
-   char *s;
    struct fileparts *fp;
    struct tdefnm *td;
-   struct token *t;
-   static char *test_largeints = "#ifdef LargeInts\nyes\n#endif\n";
-   static int first_time = 1;
 
    cur_src = src_file;
 
@@ -266,24 +259,6 @@ char *src_file;
       sym_add(TypeDefName, td->name, OtherDcl, 1);
    init_lex();
    yyparse();
-   if (first_time) {
-      first_time = 0;
-      /*
-       * Now that the standard include files have been processed, see if
-       *  Largeints is defined and make sure it matches what's in the data base.
-       */
-      s = "NoLargeInts";
-      str_src("<rtt initialization>", test_largeints,
-         (int)strlen(test_largeints));
-      while ((t = preproc()) != NULL)
-          if (strcmp(t->image, "yes"))
-             s = "LargeInts";
-      if (largeints == NULL)
-         largeints = s;
-      else if (strcmp(largeints, s) != 0)
-         err2("header file definition of LargeInts/NoLargeInts does not match ",
-            dbname);
-      }
    enable_out = 1;
 
    /*
@@ -350,8 +325,7 @@ char *src_file;
 /*
  * add_tdef - add identifier to list of typedef names.
  */
-static void add_tdef(name)
-char *name;
+static void add_tdef(char *name)
    {
    struct tdefnm *td;
 
@@ -365,9 +339,7 @@ char *name;
  * Add name of file to the output list, and if it contains "interesting"
  *  code, add it to the dependency list in the data base.
  */
-void put_c_fl(fname, keep)
-char *fname;
-int keep;
+void put_c_fl(char *fname, int keep)
    {
    struct fileparts *fp;
 
@@ -389,8 +361,7 @@ void show_usage()
 /*
  * yyerror - error routine called by yacc.
  */
-void yyerror(s)
-char *s;
+void yyerror(char *s)
    {
    struct token *t;
 
