@@ -2,43 +2,35 @@
  * data.r -- Various interpreter data tables.
  */
 
-#if !COMPILER
-
 struct b_proc Bnoproc;
 
-#ifdef EventMon
-struct b_iproc mt_llist = {
-   6, (sizeof(struct b_proc) - sizeof(struct descrip)), Ollist,
-   0, -1,  0, 0, {sizeof( "[...]")-1, "[...]"}};
-#endif					/* EventMon */
-
 
 /*
  * External declarations for function blocks.
  */
 
-#define FncDef(p,n) extern struct b_proc Cat(B,p);
-#define FncDefV(p) extern struct b_proc Cat(B,p);
+#define FncDef(p,n) extern struct b_iproc Cat(B,p);
+#define FncDefV(p) extern struct b_iproc Cat(B,p);
 #passthru #undef exit
 #undef exit
 #include "../h/fdefs.h"
 #undef FncDef
 #undef FncDefV
 
-#define OpDef(p,n,s,u) extern struct b_proc Cat(B,p);
+#define OpDef(p,n,s,u) extern struct b_iproc Cat(B,p);
 #include "../h/odefs.h"
 #undef OpDef
 
-extern struct b_proc Bbscan;
-extern struct b_proc Bescan;
-extern struct b_proc Bfield;
-extern struct b_proc Blimit;
-extern struct b_proc Bllist;
+extern struct b_iproc Bbscan;
+extern struct b_iproc Bescan;
+extern struct b_iproc Bfield;
+extern struct b_iproc Blimit;
+extern struct b_iproc Bllist;
 
 
 
 
-struct b_proc *opblks[] = {
+struct b_iproc *opblks[] = {
 	NULL,
 #define OpDef(p,n,s,u) Cat(&B,p),
 #include "../h/odefs.h"
@@ -76,18 +68,17 @@ struct b_proc *opblks[] = {
 
 struct pstrnm pntab[] = {
 
-#define FncDef(p,n) Lit(p), Cat(&B,p),
-#define FncDefV(p) Lit(p), Cat(&B,p),
+#define FncDef(p,n) { Lit(p), (struct b_proc *)Cat(&B,p) },
+#define FncDefV(p) { Lit(p), (struct b_proc *)Cat(&B,p) },
 #include "../h/fdefs.h"
 #undef FncDef
 #undef FncDefV
 
-	0,		 0
+	{ 0, 0 }
 	};
 
 int pnsize = (sizeof(pntab) / sizeof(struct pstrnm)) - 1;
 
-#endif					/* COMPILER */
 
 /*
  * Structures for built-in values.  Parts of some of these structures are
@@ -132,8 +123,6 @@ struct b_cset  fullcs = {
 		~0, ~0, ~0, ~0, ~0, ~0, ~0, ~0)
    };
 
-#if !COMPILER
-
 /*
  * Built-in csets
  */
@@ -181,29 +170,17 @@ struct b_cset  k_letters = {
    cset_display(0,  0,	0,  0,	~01,  03777, ~01, 03777,
 		0,  0,	0,  0,	0,  0,	0,  0)
    };
-#endif					/* COMPILER */
 
 /*
  * Built-in files.
  */
-
-#ifndef MultiThread
 struct b_file  k_errout = {T_File, NULL, Fs_Write};	/* &errout */
 struct b_file  k_input = {T_File, NULL, Fs_Read};	/* &input */
 struct b_file  k_output = {T_File, NULL, Fs_Write};	/* &output */
-#endif					/* MultiThread */
-
-#ifdef EventMon
-/*
- *  Real block needed for event monitoring.
- */
-struct b_real realzero = {T_Real, 0.0};
-#endif					/* EventMon */
 
 /*
  * Keyword variables.
  */
-#ifndef MultiThread
 struct descrip kywd_err = {D_Integer};  /* &error */
 struct descrip kywd_pos = {D_Integer};	/* &pos */
 struct descrip kywd_prog;		/* &progname */
@@ -213,13 +190,6 @@ struct descrip kywd_trc = {D_Integer};	/* &trace */
 struct descrip k_eventcode = {D_Null};	/* &eventcode */
 struct descrip k_eventsource = {D_Null};/* &eventsource */
 struct descrip k_eventvalue = {D_Null};	/* &eventvalue */
-
-#endif					/* MultiThread */
-
-#ifdef FncTrace
-struct descrip kywd_ftrc = {D_Integer};	/* &ftrace */
-#endif					/* FncTrace */
-
 struct descrip kywd_dmp = {D_Integer};	/* &dump */
 
 struct descrip nullptr =
@@ -239,15 +209,6 @@ struct descrip onedesc = {D_Integer};	/* integer 1 */
 struct descrip ucase;			/* string of uppercase letters */
 struct descrip zerodesc = {D_Integer};	/* integer 0 */
 
-#ifdef EventMon
-/*
- * Descriptors used by event monitoring.
- */
-struct descrip csetdesc = {D_Cset};
-struct descrip eventdesc;
-struct descrip rzerodesc = {D_Real};
-#endif					/* EventMon */
-
 /*
  * An array of all characters for use in making one-character strings.
  */
@@ -276,86 +237,89 @@ unsigned char allchars[256] = {
  */
 struct errtab errtab[] = {
 
-   101, "integer expected or out of range",
-   102, "numeric expected",
-   103, "string expected",
-   104, "cset expected",
-   105, "file expected",
-   106, "procedure or integer expected",
-   107, "record expected",
-   108, "list expected",
-   109, "string or file expected",
-   110, "string or list expected",
-   111, "variable expected",
-   112, "invalid type to size operation",
-   113, "invalid type to random operation",
-   114, "invalid type to subscript operation",
-   115, "structure expected",
-   116, "invalid type to element generator",
-   117, "missing main procedure",
-   118, "co-expression expected",
-   119, "set expected",
-   120, "two csets or two sets expected",
-   121, "function not supported",
-   122, "set or table expected",
-   123, "invalid type",
-   124, "table expected",
-   125, "list, record, or set expected",
-   126, "list or record expected",
+   { 101, "integer expected or out of range" },
+   { 102, "numeric expected" },
+   { 103, "string expected" },
+   { 104, "cset expected" },
+   { 105, "file expected" },
+   { 106, "procedure or integer expected" },
+   { 107, "record expected" },
+   { 108, "list expected" },
+   { 109, "string or file expected" },
+   { 110, "string or list expected" },
+   { 111, "variable expected" },
+   { 112, "invalid type to size operation" },
+   { 113, "invalid type to random operation" },
+   { 114, "invalid type to subscript operation" },
+   { 115, "structure expected" },
+   { 116, "invalid type to element generator" },
+   { 117, "missing main procedure" },
+   { 118, "co-expression expected" },
+   { 119, "set expected" },
+   { 120, "two csets or two sets expected" },
+   { 121, "function not supported" },
+   { 122, "set or table expected" },
+   { 123, "invalid type" },
+   { 124, "table expected" },
+   { 125, "list, record, or set expected" },
+   { 126, "list or record expected" },
+
+   /* general messages for use by code dealing with external data */
+   { 131, "external expected" },	/* not an external */
+   { 132, "incorrect external type" },	/* external of wrong flavor */
+   { 133, "invalid external value" },	/* right flavor in wrong context */
+   { 134, "malformed external value" },	/* data bogus, not just inappropriate */
 
 #ifdef Graphics
-   140, "window expected",
-   141, "program terminated by window manager",
-   142, "attempt to read/write on closed window",
-   143, "malformed event queue",
-   144, "window system error",
-   145, "bad window attribute",
-   146, "incorrect number of arguments to drawing function",
-   147, "window attribute cannot be read or written as requested",
+   { 140, "window expected" },
+   { 141, "program terminated by window manager" },
+   { 142, "attempt to read/write on closed window" },
+   { 143, "malformed event queue" },
+   { 144, "window system error" },
+   { 145, "bad window attribute" },
+   { 146, "incorrect number of arguments to drawing function" },
+   { 147, "window attribute cannot be read or written as requested" },
 #endif					/* Graphics */
 
 #ifdef FAttrib
-   160, "bad file attribute",
+   { 160, "bad file attribute" },
 #endif					/* FAttrib */
 
-   201, "division by zero",
-   202, "remaindering by zero",
-   203, "integer overflow",
-   204, "real overflow, underflow, or division by zero",
-   205, "invalid value",
-   206, "negative first argument to real exponentiation",
-   207, "invalid field name",
-   208, "second and third arguments to map of unequal length",
-   209, "invalid second argument to open",
-   210, "non-ascending arguments to detab/entab",
-   211, "by value equal to zero",
-   212, "attempt to read file not open for reading",
-   213, "attempt to write file not open for writing",
-   214, "input/output error",
-   215, "attempt to refresh &main",
-   216, "external function not found",
+   { 201, "division by zero" },
+   { 202, "remaindering by zero" },
+   { 203, "integer overflow" },
+   { 204, "real overflow, underflow, or division by zero" },
+   { 205, "invalid value" },
+   { 206, "negative first argument to real exponentiation" },
+   { 207, "invalid field name" },
+   { 208, "second and third arguments to map of unequal length" },
+   { 209, "invalid second argument to open" },
+   { 210, "non-ascending arguments to detab/entab" },
+   { 211, "by value equal to zero" },
+   { 212, "attempt to read file not open for reading" },
+   { 213, "attempt to write file not open for writing" },
+   { 214, "input/output error" },
+   { 215, "attempt to refresh &main" },
+   { 216, "external function not found" },
 
-   301, "evaluation stack overflow",
-   302, "memory violation",
-   303, "inadequate space for evaluation stack",
-   304, "inadequate space in qualifier list",
-   305, "inadequate space for static allocation",
-   306, "inadequate space in string region",
-   307, "inadequate space in block region",
-   308, "system stack overflow in co-expression",
+   { 300, "interrupted" },
+   { 301, "evaluation stack overflow" },
+   { 302, "memory violation" },
+   { 303, "inadequate space for evaluation stack" },
+   { 304, "inadequate space in qualifier list" },
+   { 305, "inadequate space for static allocation" },
+   { 306, "inadequate space in string region" },
+   { 307, "inadequate space in block region" },
+   { 308, "system stack overflow in co-expression" },
 
-#ifndef Coexpr
-   401, "co-expressions not implemented",
-#endif					/* Coexpr */
-   402, "program not compiled with debugging option",
+   { 402, "program not compiled with debugging option" },
 
-   500, "program malfunction",		/* for use by runerr() */
-   600, "vidget usage error",		/* yeah! */
+   { 500, "program malfunction" },	/* for use by runerr() */
+   { 600, "vidget usage error" },	/* yeah! */
 
-   0,	""
+   { 0,	"" }
    };
 
-#if !COMPILER
 #define OpDef(p,n,s,u) int Cat(O,p) (dptr cargp);
 #include "../h/odefs.h"
 #undef OpDef
@@ -365,25 +329,25 @@ struct errtab errtab[] = {
  *  nth word here is the routine to call.
  */
 
-int (*optab[])() = {
-	err,
+int (*optab[])(dptr) = {
+   NULL,
 #define OpDef(p,n,s,u) Cat(O,p),
 #include "../h/odefs.h"
 #undef OpDef
-   Obscan,
-   err,
-   err,
-   err,
-   err,
-   err,
-   Ocreate,
-   err,
-   err,
-   err,
-   err,
-   Oescan,
-   err,
-   Ofield
+   (int(*)(dptr))Obscan,
+   NULL,
+   NULL,
+   NULL,
+   NULL,
+   NULL,
+   (int(*)(dptr))Ocreate,
+   NULL,
+   NULL,
+   NULL,
+   NULL,
+   (int(*)(dptr))Oescan,
+   NULL,
+   (int(*)(dptr))Ofield
    };
 
 /*
@@ -393,9 +357,8 @@ int (*optab[])() = {
 #include "../h/kdefs.h"
 #undef KDef
 
-int (*keytab[])() = {
-   err,
+int (*keytab[])(dptr) = {
+   NULL,
 #define KDef(p,n) Cat(K,p),
 #include "../h/kdefs.h"
    };
-#endif					/* !COMPILER */
