@@ -7,8 +7,7 @@
  * anycmp - compare any two objects.
  */
 
-int anycmp(dp1,dp2)
-dptr dp1, dp2;
+int anycmp(dptr dp1, dptr dp2)
    {
    register int o1, o2;
    register long v1, v2, lresult;
@@ -35,8 +34,6 @@ dptr dp1, dp2;
 
    switch (Type(*dp1)) {
 
-#ifdef LargeInts
-
       case T_Integer:
 	 if (Type(*dp2) != T_Lrgint) {
             v1 = IntVal(*dp1);
@@ -56,20 +53,6 @@ dptr dp1, dp2;
 	    return Equal;
 	 return ((lresult > 0) ? Greater : Less);
 
-#else					/* LargeInts */
-
-      case T_Integer:
-         v1 = IntVal(*dp1);
-         v2 = IntVal(*dp2);
-         if (v1 < v2)
-            return Less;
-         else if (v1 == v2)
-            return Equal;
-         else
-            return Greater;
-
-#endif					/* LargeInts */
-
       case T_Coexpr:
          /*
           * Collate on co-expression id.
@@ -88,7 +71,9 @@ dptr dp1, dp2;
           * Collate on file name or window label.
           */
 	 {
+#ifdef Graphics
 	 struct descrip s1, s2; /* live only long enough to lexcmp them */
+#endif					/* Graphics */
 	 dptr ps1 = &(BlkLoc(*dp1)->file.fname);
 	 dptr ps2 = &(BlkLoc(*dp2)->file.fname);
 #ifdef Graphics
@@ -171,14 +156,15 @@ dptr dp1, dp2;
          return ((lresult > 0) ? Greater : Less);
 
       case T_External:
-	 /*
-          * Collate these values according to the relative positions of
-          *  their blocks in the heap.
-	  */
-         lresult = ((long)BlkLoc(*dp1) - (long)BlkLoc(*dp2));
-         if (lresult == 0)
-            return Equal;
-         return ((lresult > 0) ? Greater : Less);
+         /*
+          * Call associated collation function.
+          */
+         {
+         struct descrip result = callextfunc(&extlcmp, dp1, dp2);
+         long ans = result.vword.integr;
+         if (ans == 0) return Equal;
+         return ans > 0 ? Greater : Less;
+         }
 
       default:
 	 syserr("anycmp: unknown datatype.");
@@ -191,8 +177,7 @@ dptr dp1, dp2;
  * order(x) - return collating number for object x.
  */
 
-int order(dp)
-dptr dp;
+int order(dptr dp)
    {
    if (Qual(*dp))
       return 3;			     /* string */
@@ -201,17 +186,12 @@ dptr dp;
 	 return 0;
       case T_Integer:
 	 return 1;
-
-#ifdef LargeInts
       case T_Lrgint:
 	 return 1;
-#endif					/* LargeInts */
-
       case T_Real:
 	 return 2;
-
-      /* string: return 3 (see above) */
-
+      /* String (handled above): /*
+         /* return 3; */
       case T_Cset:
 	 return 4;
       case T_File:
@@ -241,8 +221,7 @@ dptr dp;
  * equiv - test equivalence of two objects.
  */
 
-int equiv(dp1, dp2)
-dptr dp1, dp2;
+int equiv(dptr dp1, dptr dp2)
    {
    register int result;
    register word i;
@@ -285,12 +264,9 @@ dptr dp1, dp2;
 	    result = (IntVal(*dp1) == IntVal(*dp2));
 	    break;
 
-#ifdef LargeInts
 	 case T_Lrgint:
 	    result = (bigcmp(dp1, dp2) == 0);
 	    break;
-#endif					/* LargeInts */
-
 
 	 case T_Real:
             GetReal(dp1, rres1);
@@ -323,8 +299,7 @@ dptr dp1, dp2;
  * lexcmp - lexically compare two strings.
  */
 
-int lexcmp(dp1, dp2)
-dptr dp1, dp2;
+int lexcmp(dptr dp1, dptr dp2)
    {
 
 
@@ -371,8 +346,7 @@ dptr dp1, dp2;
  *  the two strings that the csets would be converted into.
  */
 
-int csetcmp(cs1, cs2)
-unsigned int *cs1, *cs2;
+int csetcmp(unsigned int *cs1, unsigned int *cs2)
    {
    unsigned int nbit, mask, *cs_end;
 
