@@ -18,31 +18,7 @@ static void xtrace
  * tracebk - print a trace of procedure calls.
  */
 
-#if COMPILER
-
-void tracebk(lcl_pfp, argp)
-struct p_frame *lcl_pfp;
-dptr argp;
-   {
-   struct b_proc *cproc;
-
-   struct debug *debug;
-   word nparam;
-
-   if (lcl_pfp == NULL)
-      return;
-   debug = PFDebug(*lcl_pfp);
-   tracebk(lcl_pfp->old_pfp, lcl_pfp->old_argp);
-   cproc = debug->proc;
-   xtrace(cproc, (word)abs((int)cproc->nparam), argp, debug->old_line,
-      debug->old_fname);
-   }
-
-#else					/* COMPILER */
-
-void tracebk(lcl_pfp, argp)
-struct pf_marker *lcl_pfp;
-dptr argp;
+void tracebk(struct pf_marker *lcl_pfp, dptr argp)
    {
    struct b_proc *cproc;
 
@@ -87,34 +63,23 @@ dptr argp;
       pfp = (struct pf_marker *)(pfp->pf_efp);
       }
    }
-
-#endif					/* COMPILER */
 
 /*
  * xtrace - procedure *bp is being called with nargs arguments, the first
  *  of which is at arg; produce a trace message.
  */
-static void xtrace(bp, nargs, arg, pline, pfile)
-struct b_proc *bp;
-word nargs;
-dptr arg;
-int pline;
-char *pfile;
+static void xtrace(struct b_proc *bp,
+   word nargs, dptr arg, int pline, char *pfile)
    {
 
    if (bp == NULL)
       fprintf(stderr, "????");
    else {
-
-#if COMPILER
-       putstr(stderr, &(bp->pname));
-#else					/* COMPILER */
        if (arg[0].dword == D_Proc)
           putstr(stderr, &(bp->pname));
        else
           outimage(stderr, arg, 0);
        arg++;
-#endif					/* COMPILER */
 
        putc('(', stderr);
        while (nargs--) {
@@ -134,8 +99,7 @@ char *pfile;
 /*
  * get_name -- function to get print name of variable.
  */
-int get_name(dp1,dp0)
-   dptr dp1, dp0;
+int get_name(dptr dp1, dptr dp0)
    {
    dptr dp, varptr;
    tended union block *blkptr;
@@ -147,15 +111,9 @@ int get_name(dp1,dp0)
    word i, j, k;
    int t;
 
-#if COMPILER
-   arg1 = glbl_argp;
-   loc1 = pfp->tend.d;
-   proc = PFDebug(*pfp)->proc;
-#else					/* COMPILER */
    arg1 = &glbl_argp[1];
    loc1 = pfp->pf_locals;
    proc = &BlkLoc(*glbl_argp)->proc;
-#endif					/* COMPILER */
 
    type_case *dp1 of {
       tvsubs: {
@@ -196,14 +154,6 @@ int get_name(dp1,dp0)
             StrLen(*dp0) = 6;
             StrLoc(*dp0) = "&trace";
             }
-
-#ifdef FncTrace
-         else if (VarLoc(*dp1) == &kywd_ftrc) {
-            StrLen(*dp0) = 7;
-            StrLoc(*dp0) = "&ftrace";
-            }
-#endif					/* FncTrace */
-
          else if (VarLoc(*dp1) == &kywd_dmp) {
             StrLen(*dp0) = 5;
             StrLoc(*dp0) = "&dump";
@@ -216,21 +166,6 @@ int get_name(dp1,dp0)
             syserr("name: unknown integer keyword variable");
 
       kywdevent:
-#ifdef MultiThread
-         if (VarLoc(*dp1) == &curpstate->eventsource) {
-            StrLen(*dp0) = 12;
-            StrLoc(*dp0) = "&eventsource";
-            }
-         else if (VarLoc(*dp1) == &curpstate->eventval) {
-            StrLen(*dp0) = 11;
-            StrLoc(*dp0) = "&eventvalue";
-            }
-         else if (VarLoc(*dp1) == &curpstate->eventcode) {
-            StrLen(*dp0) = 10;
-            StrLoc(*dp0) = "&eventcode";
-            }
-         else
-#endif					/* MultiThread */
             syserr("name: unknown event keyword variable");
 
       kywdwin: {
@@ -293,20 +228,11 @@ int get_name(dp1,dp0)
                   i = varptr - &blkptr->lelem.lslots[blkptr->lelem.first] + 1;
                   if (i < 1)
                      i += blkptr->lelem.nslots;
-#ifdef ListFix
-                  while (BlkType(blkptr->lelem.listprev) == T_Lelem) {
-#else					/* ListFix */
                   while (blkptr->lelem.listprev != NULL) {
-#endif					/* ListFix */
                      blkptr = blkptr->lelem.listprev;
                      i += blkptr->lelem.nused;
                      }
-#ifdef ListFix
-                  sprintf(sbuf,"list_%d[%ld]",
-			  (long)blkptr->lelem.listprev->list.id, (long)i);
-#else					/* ListFix */
                   sprintf(sbuf,"L[%ld]", (long)i);
-#endif					/* ListFix */
                   i = strlen(sbuf);
                   Protect(StrLoc(*dp0) = alcstr(sbuf,i), return Error);
                   StrLen(*dp0) = i;
@@ -314,16 +240,8 @@ int get_name(dp1,dp0)
                case T_Record:		/* record */
                   i = varptr - blkptr->record.fields;
                   proc = &blkptr->record.recdesc->proc;
-
-#ifdef TableFix
-                  sprintf(sbuf,"record %s_%d.%s", StrLoc(proc->recname),
-			  blkptr->record.id,
-			  StrLoc(proc->lnames[i]));
-#else
                   sprintf(sbuf,"%s.%s", StrLoc(proc->recname),
 			  StrLoc(proc->lnames[i]));
-#endif
-
                   i = strlen(sbuf);
                   Protect(StrLoc(*dp0) = alcstr(sbuf,i), return Error);
                   StrLen(*dp0) = i;
@@ -334,110 +252,17 @@ int get_name(dp1,dp0)
                       return Error;
                   break;
                default:		/* none of the above */
-#ifdef EventMon
-                  *dp0 = emptystr;
-#else					/* EventMon */
                   syserr("name: invalid structure reference");
-#endif					/* EventMon */
-
                }
            }
       }
    return Succeeded;
    }
 
-#if COMPILER
-#begdef PTraceSetup()
-   struct b_proc *proc;
-
-   --k_trace;
-   showline(file_name, line_num);
-   showlevel(k_level);
-   proc = PFDebug(*pfp)->proc; /* get address of procedure block */
-   putstr(stderr, &proc->pname);
-#enddef
-
-/*
- * ctrace - a procedure is being called; produce a trace message.
- */
-void ctrace()
-   {
-   dptr arg;
-   int n;
-
-   PTraceSetup();
-
-   putc('(', stderr);
-   arg = glbl_argp;
-   n = abs((int)proc->nparam);
-   while (n--) {
-      outimage(stderr, arg++, 0);
-      if (n)
-         putc(',', stderr);
-      }
-   putc(')', stderr);
-   putc('\n', stderr);
-   fflush(stderr);
-   }
-
-/*
- * rtrace - a procedure is returning; produce a trace message.
- */
-
-void rtrace()
-   {
-   PTraceSetup();
-
-   fprintf(stderr, " returned ");
-   outimage(stderr, pfp->rslt, 0);
-   putc('\n', stderr);
-   fflush(stderr);
-   }
-
-/*
- * failtrace - procedure named s is failing; produce a trace message.
- */
-
-void failtrace()
-   {
-   PTraceSetup();
-
-   fprintf(stderr, " failed\n");
-   fflush(stderr);
-   }
-
-/*
- * strace - a procedure is suspending; produce a trace message.
- */
-
-void strace()
-   {
-   PTraceSetup();
-
-   fprintf(stderr, " suspended ");
-   outimage(stderr, pfp->rslt, 0);
-   putc('\n', stderr);
-   fflush(stderr);
-   }
-
-/*
- * atrace - a procedure is being resumed; produce a trace message.
- */
-void atrace()
-   {
-   PTraceSetup();
-
-   fprintf(stderr, " resumed\n");
-   fflush(stderr);
-   }
-#endif					/* COMPILER */
-
 /*
  * keyref(bp,dp) -- print name of subscripted table
  */
-static int keyref(bp, dp)
-   union block *bp;
-   dptr dp;
+static int keyref(union block *bp, dptr dp)
    {
    char *s, *s2;
    char sbuf[100];			/* buffer; might be too small */
@@ -451,16 +276,7 @@ static int keyref(bp, dp)
     */
    s2 = StrLoc(*dp);
    len = StrLen(*dp);
-#ifdef TableFix
-   if (BlkType(bp) == T_Tvtbl)
-      bp = bp->tvtbl.clink;
-   else
-      while(BlkType(bp) == T_Telem)
-         bp = bp->telem.clink;
-   sprintf(sbuf, "table_%d[", bp->table.id);
-#else					/* TableFix */
    strcpy(sbuf, "T[");
-#endif					/* TableFix */
    { char * dest = sbuf + strlen(sbuf);
    strncpy(dest, s2, len);
    dest[len] = '\0';
@@ -473,37 +289,23 @@ static int keyref(bp, dp)
    return Succeeded;
    }
 
-#ifdef Coexpr
 /*
  * cotrace -- a co-expression context switch; produce a trace message.
  */
-void cotrace(ccp, ncp, swtch_typ, valloc)
-struct b_coexpr *ccp;
-struct b_coexpr *ncp;
-int swtch_typ;
-dptr valloc;
+void cotrace(struct b_coexpr *ccp, struct b_coexpr *ncp,
+   int swtch_typ, dptr valloc)
    {
    struct b_proc *proc;
-
-#if !COMPILER
    inst t_ipc;
-#endif					/* !COMPILER */
 
    --k_trace;
 
-#if COMPILER
-   showline(ccp->file_name, ccp->line_num);
-   proc = PFDebug(*ccp->es_pfp)->proc;     /* get address of procedure block */
-#else					/* COMPILER */
-
    /*
     * Compute the ipc of the instruction causing the context switch.
     */
    t_ipc.op = ipc.op - 1;
    showline(findfile(t_ipc.opnd), findline(t_ipc.opnd));
    proc = (struct b_proc *)BlkLoc(*glbl_argp);
-#endif					/* COMPILER */
-
    showlevel(k_level);
    putstr(stderr, &proc->pname);
    fprintf(stderr,"; co-expression_%ld ", (long)ccp->id);
@@ -525,14 +327,11 @@ dptr valloc;
    fprintf(stderr,"co-expression_%ld\n", (long)ncp->id);
    fflush(stderr);
    }
-#endif					/* Coexpr */
 
 /*
  * showline - print file and line number information.
  */
-static void showline(f, l)
-char *f;
-int l;
+static void showline(char *f, int l)
    {
    int i;
 
@@ -550,8 +349,7 @@ int l;
 /*
  * showlevel - print "| " n times.
  */
-static void showlevel(n)
-register int n;
+static void showlevel(int n)
    {
    while (n-- > 0) {
       putc('|', stderr);
@@ -559,13 +357,10 @@ register int n;
       }
    }
 
-#if !COMPILER
-
 #include "../h/opdefs.h"
 
-
 extern struct descrip value_tmp;		/* argument of Op_Apply */
-extern struct b_proc *opblks[];
+extern struct b_iproc *opblks[];
 
 
 /*
@@ -673,8 +468,7 @@ static void ttrace()
          break;
 
       default:
-
-         bp = opblks[lastop];
+         bp = (struct b_proc *)opblks[lastop];
          nargs = abs((int)bp->nparam);
          putc('{', stderr);
          if (lastop == Op_Bang || lastop == Op_Random)
@@ -704,10 +498,7 @@ oneop:
  * ctrace - procedure named s is being called with nargs arguments, the first
  *  of which is at arg; produce a trace message.
  */
-void ctrace(dp, nargs, arg)
-dptr dp;
-int nargs;
-dptr arg;
+void ctrace(dptr dp, int nargs, dptr arg)
    {
 
    showline(findfile(ipc.opnd), findline(ipc.opnd));
@@ -728,9 +519,7 @@ dptr arg;
  * rtrace - procedure named s is returning *rval; produce a trace message.
  */
 
-void rtrace(dp, rval)
-dptr dp;
-dptr rval;
+void rtrace(dptr dp, dptr rval)
    {
    inst t_ipc;
 
@@ -751,8 +540,7 @@ dptr rval;
  * failtrace - procedure named s is failing; produce a trace message.
  */
 
-void failtrace(dp)
-dptr dp;
+void failtrace(dptr dp)
    {
    inst t_ipc;
 
@@ -772,9 +560,7 @@ dptr dp;
  * strace - procedure named s is suspending *rval; produce a trace message.
  */
 
-void strace(dp, rval)
-dptr dp;
-dptr rval;
+void strace(dptr dp, dptr rval)
    {
    inst t_ipc;
 
@@ -795,8 +581,7 @@ dptr rval;
  * atrace - procedure named s is being resumed; produce a trace message.
  */
 
-void atrace(dp)
-dptr dp;
+void atrace(dptr dp)
    {
    inst t_ipc;
 
@@ -812,13 +597,10 @@ dptr dp;
    fflush(stderr);
    }
 
-#ifdef Coexpr
 /*
  * coacttrace -- co-expression is being activated; produce a trace message.
  */
-void coacttrace(ccp, ncp)
-struct b_coexpr *ccp;
-struct b_coexpr *ncp;
+void coacttrace(struct b_coexpr *ccp, struct b_coexpr *ncp)
    {
    struct b_proc *bp;
    inst t_ipc;
@@ -840,9 +622,7 @@ struct b_coexpr *ncp;
 /*
  * corettrace -- return from co-expression; produce a trace message.
  */
-void corettrace(ccp, ncp)
-struct b_coexpr *ccp;
-struct b_coexpr *ncp;
+void corettrace(struct b_coexpr *ccp, struct b_coexpr *ncp)
    {
    struct b_proc *bp;
    inst t_ipc;
@@ -864,9 +644,7 @@ struct b_coexpr *ncp;
 /*
  * cofailtrace -- failure return from co-expression; produce a trace message.
  */
-void cofailtrace(ccp, ncp)
-struct b_coexpr *ccp;
-struct b_coexpr *ncp;
+void cofailtrace(struct b_coexpr *ccp, struct b_coexpr *ncp)
    {
    struct b_proc *bp;
    inst t_ipc;
@@ -883,23 +661,13 @@ struct b_coexpr *ncp;
       (long)ccp->id, (long)ncp->id);
    fflush(stderr);
    }
-#endif					/* Coexpr */
-#endif					/* !COMPILER */
 
 /*
  * Service routine to display variables in given number of
  *  procedure calls to file f.
  */
 
-int xdisp(fp,dp,count,f)
-#if COMPILER
-   struct p_frame *fp;
-#else					/* COMPILER */
-   struct pf_marker *fp;
-#endif					/* COMPILER */
-   register dptr dp;
-   int count;
-   FILE *f;
+int xdisp(struct pf_marker *fp, dptr dp, int count, FILE *f)
    {
    register dptr np;
    register int n;
@@ -909,13 +677,7 @@ int xdisp(fp,dp,count,f)
    while (count--) {		/* go back through 'count' frames */
       if (fp == NULL)
          break;       /* needed because &level is wrong in co-expressions */
-
-#if COMPILER
-      bp = PFDebug(*fp)->proc;	/* get address of procedure block */
-#else					/* COMPILER */
       bp = (struct b_proc *)BlkLoc(*dp++); /* get addr of procedure block */
-      /* #%#% was: no post-increment there, but *pre*increment dp below */
-#endif					/* COMPILER */
 
       /*
        * Print procedure name.
@@ -939,11 +701,7 @@ int xdisp(fp,dp,count,f)
       /*
        * Print locals.
        */
-#if COMPILER
-      dp = fp->tend.d;
-#else					/* COMPILER */
       dp = &fp->pf_locals[0];
-#endif					/* COMPILER */
       for (n = bp->ndynam; n > 0; n--) {
          fprintf(f, "   ");
          putstr(f, np);
@@ -965,26 +723,14 @@ int xdisp(fp,dp,count,f)
          putc('\n', f);
          np++;
          }
-
-#if COMPILER
-      dp = fp->old_argp;
-      fp = fp->old_pfp;
-#else					/* COMPILER */
       dp = fp->pf_argp;
       fp = fp->pf_pfp;
-#endif					/* COMPILER */
       }
 
    /*
     * Print globals.  Sort names in lexical order using temporary index array.
     */
-
-#if COMPILER
-   nglobals = n_globals;
-#else					/* COMPILER */
    nglobals = eglobals - globals;
-#endif					/* COMPILER */
-
    indices = (word *)malloc(nglobals * sizeof(word));
    if (indices == NULL)
       return Failed;
@@ -1009,8 +755,7 @@ int xdisp(fp,dp,count,f)
 /*
  * glbcmp - compare the names of two globals using their temporary indices.
  */
-static int glbcmp (pi, pj)
-char *pi, *pj;
+static int glbcmp(char *pi, char *pj)
    {
    register word i = *(word *)pi;
    register word j = *(word *)pj;
