@@ -3,8 +3,6 @@
  *  Large integer arithmetic
  */
 
-#ifdef LargeInts
-
 extern int over_flow;
 
 /*
@@ -140,9 +138,7 @@ static word cmpi1	(DIGIT *u, word k, word n);
  * mkdesc -- put value into a descriptor
  */
 
-static int mkdesc(x, dx)
-struct b_bignum *x;
-dptr dx;
+static int mkdesc(struct b_bignum *x, dptr dx)
 {
    word xlen, cmp;
    static DIGIT maxword[WORDLEN] = { 1 << ((WordBits - 1) % NB) };
@@ -165,7 +161,7 @@ dptr dx;
       word i;
 
       for (i = x->msd; ++i <= x->lsd; )
-         val = (val << NB) - x->digits[i];
+         val = (word)((uword)val << NB) - x->digits[i];
       if (!x->sign)
 	 val = -val;
       dx->dword = D_Integer;
@@ -182,10 +178,7 @@ dptr dx;
  *  i -> big
  */
 
-static void itobig(i, x, dx)
-word i;
-struct b_bignum *x;
-dptr dx;
+static void itobig(word i, struct b_bignum *x, dptr dx)
 {
    x->lsd = WORDLEN - 1;
    x->msd = WORDLEN;
@@ -222,11 +215,11 @@ dptr dx;
  *  string -> bignum
  */
 
-word bigradix(sign, r, s, end_s, result)
-int sign;                      /* '-' or not */
-int r;                          /* radix 2 .. 36 */
-char *s, *end_s;                        /* input string */
-union numeric *result;          /* output T_Integer or T_Lrgint */
+word bigradix(
+   int sign,			/* '-' or not */
+   int r,			/* radix 2 .. 36 */
+   char *s, char *end_s,	/* input string */
+   union numeric *result)	/* output T_Integer or T_Lrgint */
 {
    struct b_bignum *b;
    DIGIT *bd;
@@ -281,8 +274,7 @@ union numeric *result;          /* output T_Integer or T_Lrgint */
  *  bignum -> real
  */
 
-double bigtoreal(da)
-dptr da;
+int bigtoreal(dptr da, double *d)
 {
    word i;
    double r = 0;
@@ -290,44 +282,35 @@ dptr da;
 
    for (i = b->msd; i <= b->lsd; i++)
       r = r * B + b->digits[i];
-
-   return (b->sign ? -r : r);
+   if (isinf(r))
+      return 0;
+   *d = (b->sign ? -r : r);
+   return 1;
 }
 
 /*
  *  real -> bignum
  */
 
-int realtobig(da, dx)
-dptr da, dx;
+int realtobig(dptr da, dptr dx)
 {
-
-#ifdef Double
    double x;
-#else					/* Double */
-   double x = BlkLoc(*da)->realblk.realval;
-#endif					/* Double */
 
+   GetReal(da, x);
+   return doubletobig(x, dx);
+}
+
+/*
+ *  double -> bignum
+ */
+
+int doubletobig(double x, dptr dx)
+{
    struct b_bignum *b;
    word i, blen;
    word d;
    int sgn;
 
-#ifdef Double
-	{
-		int	*rp, *rq;
-		rp = (int *) &(BlkLoc(*da)->realblk.realval);
-		rq = (int *) &x;
-		*rq++ = *rp++;
-		*rq = *rp;
-	}
-#endif					/* Double */
-
-   if (x > 0.9999 * MinLong && x < 0.9999 * MaxLong) {
-      MakeInt((word)x, dx);
-      return Succeeded;		/* got lucky; a simple integer suffices */
-      }
-
    if (sgn = x < 0)
       x = -x;
    blen = ln(x) / ln(B) + 0.99;
@@ -353,8 +336,7 @@ dptr da, dx;
  *  bignum -> string
  */
 
-int bigtos(da, dx)
-dptr da, dx;
+int bigtos(dptr da, dptr dx)
 {
    tended struct b_bignum *a, *temp;
    word alen = LEN(LrgInt(da));
@@ -389,9 +371,7 @@ dptr da, dx;
  *  bignum -> file
  */
 
-void bigprint(f, da)
-FILE *f;
-dptr da;
+void bigprint(FILE *f, dptr da)
 {
    struct b_bignum *a, *temp;
    word alen = LEN(LrgInt(da));
@@ -424,10 +404,7 @@ dptr da;
 /*
  * decout - given a base B digit string, print the number in base 10.
  */
-static void decout(f, n, l)
-FILE *f;
-DIGIT *n;
-word l;
+static void decout(FILE *f, DIGIT *n, word l)
 {
    DIGIT i = divi1(n, (word)10, n, l);
 
@@ -440,8 +417,7 @@ word l;
  *  da -> dx
  */
 
-int cpbignum(da, dx)
-dptr da, dx;
+int cpbignum(dptr da, dptr dx)
 {
    struct b_bignum *a, *x;
    word alen = LEN(LrgInt(da));
@@ -459,9 +435,7 @@ dptr da, dx;
  *  da + db -> dx
  */
 
-int bigadd(da, db, dx)
-dptr da, db;
-dptr dx;
+int bigadd(dptr da, dptr db, dptr dx)
 {
    tended struct b_bignum *a, *b;
    struct b_bignum *x;
@@ -572,8 +546,7 @@ dptr dx;
  *  da - db -> dx
  */
 
-int bigsub(da, db, dx)
-dptr da, db, dx;
+int bigsub(dptr da, dptr db, dptr dx)
 {
    struct descrip td;
    char tdigits[INTBIGBLK];
@@ -746,8 +719,7 @@ dptr da, db, dx;
  *  da * db -> dx
  */
 
-int bigmul(da, db, dx)
-dptr da, db, dx;
+int bigmul(dptr da, dptr db, dptr dx)
 {
    tended struct b_bignum *a, *b;
    struct b_bignum *x;
@@ -783,8 +755,7 @@ dptr da, db, dx;
  *  da / db -> dx
  */
 
-int bigdiv(da, db, dx)
-dptr da, db, dx;
+int bigdiv(dptr da, dptr db, dptr dx)
 {
    tended struct b_bignum *a, *b, *x, *tu, *tv;
    word alen, blen;
@@ -832,8 +803,7 @@ dptr da, db, dx;
  *  da % db -> dx
  */
 
-int bigmod(da, db, dx)
-dptr da, db, dx;
+int bigmod(dptr da, dptr db, dptr dx)
 {
    tended struct b_bignum *a, *b, *x, *temp, *tu, *tv;
    word alen, blen;
@@ -885,8 +855,7 @@ dptr da, db, dx;
  *  -i -> dx
  */
 
-int bigneg(da, dx)
-dptr da, dx;
+int bigneg(dptr da, dptr dx)
 {
    struct descrip td;
    char tdigits[INTBIGBLK];
@@ -908,8 +877,7 @@ dptr da, dx;
  *  da ^ db -> dx
  */
 
-int bigpow(da, db, dx)
-dptr da, db, dx;
+int bigpow(dptr da, dptr db, dptr dx)
 {
 
    if (Type(*db) == T_Lrgint) {
@@ -984,9 +952,7 @@ dptr da, db, dx;
       return bigpowii(IntVal(*da), IntVal(*db), dx);
 }
 
-int bigpowri( a, db, drslt )
-double a;
-dptr   db, drslt;
+int bigpowri(double a, dptr db, dptr drslt)
 {
    register double retval;
    register word n;
@@ -1030,8 +996,7 @@ dptr   db, drslt;
  *  iand(da, db) -> dx
  */
 
-int bigand(da, db, dx)
-dptr da, db, dx;
+int bigand(dptr da, dptr db, dptr dx)
 {
    tended struct b_bignum *a, *b, *x, *tad, *tbd;
    word alen, blen, xlen;
@@ -1180,8 +1145,7 @@ dptr da, db, dx;
  *  ior(da, db) -> dx
  */
 
-int bigor(da, db, dx)
-dptr da, db, dx;
+int bigor(dptr da, dptr db, dptr dx)
 {
    tended struct b_bignum *a, *b, *x, *tad, *tbd;
    word alen, blen, xlen;
@@ -1330,8 +1294,7 @@ dptr da, db, dx;
  *  xor(da, db) -> dx
  */
 
-int bigxor(da, db, dx)
-dptr da, db, dx;
+int bigxor(dptr da, dptr db, dptr dx)
 {
    tended struct b_bignum *a, *b, *x, *tad, *tbd;
    word alen, blen, xlen;
@@ -1480,8 +1443,7 @@ dptr da, db, dx;
  *  bigshift(da, db) -> dx
  */
 
-int bigshift(da, db, dx)
-dptr da, db, dx;
+int bigshift(dptr da, dptr db, dptr dx)
 {
    tended struct b_bignum *a, *x, *tad;
    word alen;
@@ -1533,7 +1495,7 @@ dptr da, db, dx;
       if (a->sign) {
          x->sign = 1;
          *DIG(x,0) |=
-            B - (1 << r);
+            B - (1L << r);
          compl1(DIG(x,0),
                 DIG(x,0),
                 xlen);
@@ -1548,14 +1510,12 @@ dptr da, db, dx;
  *  positive if da > db
  */
 
-word bigcmp(da, db)
-dptr da, db;
+word bigcmp(dptr da, dptr db)
 {
-   struct b_bignum *a = LrgInt(da);
-   struct b_bignum *b = LrgInt(db);
-   word alen, blen;
-
    if (Type(*da) == T_Lrgint && Type(*db) == T_Lrgint) {
+      word alen, blen;
+      struct b_bignum *a = LrgInt(da);
+      struct b_bignum *b = LrgInt(db);
       if (a->sign != b->sign)
          return (b->sign - a->sign);
       alen = LEN(a);
@@ -1582,8 +1542,7 @@ dptr da, db;
  *  ?da -> dx
  */
 
-int bigrand(da, dx)
-dptr da, dx;
+int bigrand(dptr da, dptr dx)
 {
    tended struct b_bignum *x, *a, *td, *tu, *tv;
    word alen = LEN(LrgInt(da));
@@ -1619,9 +1578,7 @@ dptr da, dx;
  *  da + i -> dx
  */
 
-static int bigaddi(da, i, dx)
-dptr da, dx;
-word i;
+static int bigaddi(dptr da, word i, dptr dx)
 {
    tended struct b_bignum *a;
    struct b_bignum *x;
@@ -1663,9 +1620,7 @@ word i;
  *  da - i -> dx
  */
 
-static int bigsubi(da, i, dx)
-dptr da, dx;
-word i;
+static int bigsubi(dptr da, word i, dptr dx)
 {
    tended struct b_bignum *a;
    struct b_bignum *x;
@@ -1707,9 +1662,7 @@ word i;
  *  da * i -> dx
  */
 
-static int bigmuli(da, i, dx)
-dptr da, dx;
-word i;
+static int bigmuli(dptr da, word i, dptr dx)
 {
    tended struct b_bignum *a;
    struct b_bignum *x;
@@ -1745,9 +1698,7 @@ word i;
  *  da / i -> dx
  */
 
-static int bigdivi(da, i, dx)
-dptr da, dx;
-word i;
+static int bigdivi(dptr da, word i, dptr dx)
 {
    tended struct b_bignum *a;
    struct b_bignum *x;
@@ -1782,9 +1733,7 @@ word i;
  *  da % i -> dx
  */
 
-static int bigmodi(da, i, dx)
-dptr da, dx;
-word i;
+static int bigmodi(dptr da, word i, dptr dx)
 {
    tended struct b_bignum *a, *temp;
    word alen;
@@ -1817,16 +1766,14 @@ word i;
  *  da ^ i -> dx
  */
 
-static int bigpowi(da, i, dx)
-dptr da, dx;
-word i;
+static int bigpowi(dptr da, word i, dptr dx)
 {
    int n = WordBits;
 
    if (i > 0) {
       /* scan bits left to right.  skip leading 1. */
       while (--n >= 0)
-         if (i & ((word)1 << n))
+         if (i & ((uword)1 << n))
 	    break;
       /* then, for each zero, square the partial result;
          for each one, square it and multiply it by a */
@@ -1834,7 +1781,7 @@ word i;
       while (--n >= 0) {
          if (bigmul(dx, dx, dx) == Error)
 	    return Error;
-         if (i & ((word)1 << n))
+         if (i & ((uword)1 << n))
             if (bigmul(dx, da, dx) == Error)
 	       return Error;
          }
@@ -1852,9 +1799,7 @@ word i;
  *  a ^ i -> dx
  */
 
-static int bigpowii(a, i, dx)
-word a, i;
-dptr dx;
+static int bigpowii(word a, word i, dptr dx)
 {
    word x, y;
    int n = WordBits;
@@ -1882,7 +1827,7 @@ dptr dx;
 
       /* scan bits left to right.  skip leading 1. */
       while (--n >= 0)
-         if (i & ((word)1 << n))
+         if (i & ((uword)1 << n))
 	    break;
       /* then, for each zero, square the partial result;
          for each one, square it and multiply it by a */
@@ -1903,7 +1848,7 @@ dptr dx;
                isbig = (Type(*dx) == T_Lrgint);
                }
             }
-         if (i & ((word)1 << n)) {
+         if (i & ((uword)1 << n)) {
             if (isbig) {
                if (bigmuli(dx, a, dx) == Error)
 		  return Error;
@@ -1934,9 +1879,7 @@ dptr dx;
  *  positive if da > i
  */
 
-static word bigcmpi(da, i)
-dptr da;
-word i;
+static word bigcmpi(dptr da, word i)
 {
    struct b_bignum *a = LrgInt(da);
    word alen = LEN(a);
@@ -1973,9 +1916,7 @@ word i;
  *  returns carry, 0 or 1
  */
 
-static DIGIT add1(u, v, w, n)
-DIGIT *u, *v, *w;
-word n;
+static DIGIT add1(DIGIT *u, DIGIT *v, DIGIT *w, word n)
 {
    uword dig, carry;
    word i;
@@ -1995,9 +1936,7 @@ word n;
  *  returns carry, 0 or -1
  */
 
-static word sub1(u, v, w, n)
-DIGIT *u, *v, *w;
-word n;
+static word sub1(DIGIT *u, DIGIT *v, DIGIT *w, word n)
 {
    uword dig, carry;
    word i;
@@ -2015,9 +1954,7 @@ word n;
  *  (u,n) * (v,m) -> (w,m+n)
  */
 
-static void mul1(u, v, w, n, m)
-DIGIT *u, *v, *w;
-word n, m;
+static void mul1(DIGIT *u, DIGIT *v, DIGIT *w, word n, word m)
 {
    word i, j;
    uword dig, carry;
@@ -2041,10 +1978,8 @@ word n, m;
  *  if q or r is NULL, the quotient or remainder is discarded
  */
 
-static int div1(a, b, q, r, m, n, tu, tv)
-DIGIT *a, *b, *q, *r;
-word m, n;
-struct b_bignum *tu, *tv;
+static int div1(DIGIT *a, DIGIT *b, DIGIT *q, DIGIT *r,
+   word m, word n, struct b_bignum *tu, struct b_bignum *tv)
 {
    uword qhat, rhat;
    uword dig, carry;
@@ -2057,7 +1992,7 @@ struct b_bignum *tu, *tv;
 
    /* D1 */
    for (d = 0; d < NB; d++)
-      if (b[0] & (1 << (NB - 1 - d)))
+      if (b[0] & (1L << (NB - 1 - d)))
          break;
 
    u[0] = shifti1(a, d, (DIGIT)0, &u[1], m+n);
@@ -2123,9 +2058,7 @@ struct b_bignum *tu, *tv;
  *
  */
 
-static void compl1(u, w, n)
-DIGIT *u, *w;
-word n;
+static void compl1(DIGIT *u, DIGIT *w, word n)
 {
    uword dig, carry = 0;
    word i;
@@ -2141,9 +2074,7 @@ word n;
  *  (u,n) : (v,n)
  */
 
-static word cmp1(u, v, n)
-DIGIT *u, *v;
-word n;
+static word cmp1(DIGIT *u, DIGIT *v, word n)
 {
    word i;
 
@@ -2160,10 +2091,7 @@ word n;
  *  returns carry, 0 or 1
  */
 
-static DIGIT addi1(u, k, w, n)
-DIGIT *u, *w;
-word k;
-word n;
+static DIGIT addi1(DIGIT *u, word k, DIGIT *w, word n)
 {
    uword dig, carry;
    word i;
@@ -2184,10 +2112,7 @@ word n;
  *  u must be greater than k
  */
 
-static void subi1(u, k, w, n)
-DIGIT *u, *w;
-word k;
-word n;
+static void subi1(DIGIT *u, word k, DIGIT *w, word n)
 {
    uword dig, carry;
    word i;
@@ -2207,11 +2132,7 @@ word n;
  *  returns carry, 0 .. B-1
  */
 
-static DIGIT muli1(u, k, c, w, n)
-DIGIT *u, *w;
-word k;
-int c;
-word n;
+static DIGIT muli1(DIGIT *u, word k, int c, DIGIT *w, word n)
 {
    uword dig, carry;
    word i;
@@ -2232,10 +2153,7 @@ word n;
  *  returns remainder, 0 .. B-1
  */
 
-static DIGIT divi1(u, k, w, n)
-DIGIT *u, *w;
-word k;
-word n;
+static DIGIT divi1(DIGIT *u, word k, DIGIT *w, word n)
 {
    uword dig, remain;
    word i;
@@ -2257,10 +2175,7 @@ word n;
  *  returns carry, 0 .. B-1
  */
 
-static DIGIT shifti1(u, k, c, w, n)
-DIGIT *u, c, *w;
-word k;
-word n;
+static DIGIT shifti1(DIGIT *u, word k, DIGIT c, DIGIT *w, word n)
 {
    uword dig;
    word i;
@@ -2284,10 +2199,7 @@ word n;
  *  k in 0 .. B-1
  */
 
-static word cmpi1(u, k, n)
-DIGIT *u;
-word k;
-word n;
+static word cmpi1(DIGIT *u, word k, word n)
 {
    word i;
 
@@ -2298,5 +2210,3 @@ word n;
       return 0;
    return u[n - 1] > (DIGIT)k ? 1 : -1;
 }
-
-#endif					/* LargeInts */
