@@ -20,20 +20,13 @@ static void adjust		(char *source, char *dest);
 static void compact		(char *source);
 static void mvc		(uword n, char *src, char *dest);
 
-#ifdef MultiThread
-static void markprogram	(struct progstate *pstate);
-#endif					/*MultiThread*/
-
 /*
  * Variables
  */
-
-#ifndef MultiThread
 word coll_stat = 0;             /* collections in static region */
 word coll_str = 0;              /* collections in string region */
 word coll_blk = 0;              /* collections in block region */
 word coll_tot = 0;              /* total collections */
-#endif					/* MultiThread */
 word alcnum = 0;                /* co-expressions allocated since g.c. */
 
 dptr *quallist;                 /* string qualifier list */
@@ -89,13 +82,7 @@ int firstd[] = {
      0,                       /* T_Real (3), real number */
      0,                       /* T_Cset (4), cset */
      3*WordSize,              /* T_File (5), file block */
-
-#ifdef MultiThread
-     8*WordSize,              /* T_Proc (6), procedure block */
-#else					/* MultiThread */
      7*WordSize,              /* T_Proc (6), procedure block */
-#endif					/* MultiThread */
-
      4*WordSize,              /* T_Record (7), record block */
      0,                       /* T_List (8), list header block */
      7*WordSize,              /* T_Lelem (9), list element block */
@@ -106,13 +93,7 @@ int firstd[] = {
      3*WordSize,              /* T_Tvtbl (14), table element trapped variable */
      0,                       /* T_Slots (15), set/table hash block */
      3*WordSize,              /* T_Tvsubs (16), substring trapped variable */
-
-#if COMPILER
-     2*WordSize,              /* T_Refresh (17), refresh block */
-#else					/* COMPILER */
      (4+Wsizeof(struct pf_marker))*WordSize, /* T_Refresh (17), refresh block */
-#endif					/* COMPILER */
-
     -1,                       /* T_Coexpr (18), co-expression block */
      0,                       /* T_External (19), external block */
      -1,                      /* T_Kywdint (20), integer keyword variable */
@@ -252,35 +233,17 @@ uword segsize[] = {
  * initalloc - initialization routine to allocate memory regions
  */
 
-#if COMPILER
-void initalloc()
+void initalloc(word codesize)
    {
 
-#else					/* COMPILER */
-#ifdef MultiThread
-void initalloc(codesize,p)
-struct progstate *p;
-#else					/* MultiThread */
-void initalloc(codesize)
-#endif					/* MultiThread */
-word codesize;
-   {
-#ifdef MultiThread
-   struct region *ps, *pb;
-#endif
-
    if ((uword)codesize > (unsigned)MaxBlock)
       error(NULL, "icode file too large");
    /*
     * Allocate icode region
     */
-#ifdef MultiThread
-   if (codesize)
-#endif					/* MultiThread */
    if ((code = (char *)AllocReg(codesize)) == NULL)
       error(NULL,
 	 "insufficient memory, corrupted icode file, or wrong platform");
-#endif					/* COMPILER */
 
    /*
     * Set up allocated memory.	The regions are:
@@ -290,25 +253,6 @@ word codesize;
     *	Qualifier list
     */
 
-#ifdef MultiThread
-   ps = p->stringregion;
-   ps->free = ps->base = (char *)AllocReg(ps->size);
-   if (ps->free == NULL)
-      error(NULL, "insufficient memory for string region");
-   ps->end = ps->base + ps->size;
-
-   pb = p->blockregion;
-   pb->free = pb->base = (char *)AllocReg(pb->size);
-   if (pb->free == NULL)
-      error(NULL, "insufficient memory for block region");
-   pb->end = pb->base + pb->size;
-
-   if (p == &rootpstate) {
-      if ((quallist = (dptr *)malloc(qualsize)) == NULL)
-         error(NULL, "insufficient memory for qualifier list");
-      equallist = (dptr *)((char *)quallist + qualsize);
-      }
-#else					/* MultiThread */
    {
    uword t1, t2;
    t1 = ssize;
@@ -331,23 +275,16 @@ word codesize;
    if ((quallist = (dptr *)malloc(qualsize)) == NULL)
       error(NULL, "insufficient memory for qualifier list");
    equallist = (dptr *)((char *)quallist + qualsize);
-#endif					/* MultiThread */
    }
 
 /*
  * collect - do a garbage collection of currently active regions.
  */
 
-int collect(region)
-int region;
+int collect(int region)
    {
    struct b_coexpr *cp;
 
-#ifdef EventMon
-   if (!noMTevents)
-      EVVal((word)region,E_Collect);
-#endif					/* EventMon */
-
    switch (region) {
       case Static:
          coll_stat++;
@@ -366,11 +303,8 @@ int region;
    /*
     * Garbage collection cannot be done until initialization is complete.
     */
-
-#if !COMPILER
    if (sp == NULL)
       return 0;
-#endif					/* !COMPILER */
 
    /*
     * Sync the values (used by sweep) in the coexpr block for &current
@@ -378,13 +312,10 @@ int region;
     */
    cp = (struct b_coexpr *)BlkLoc(k_current);
    cp->es_tend = tend;
-
-#if !COMPILER
    cp->es_pfp = pfp;
    cp->es_gfp = gfp;
    cp->es_efp = efp;
    cp->es_sp = sp;
-#endif					/* !COMPILER */
 
    /*
     * Reset qualifier list.
@@ -395,18 +326,13 @@ int region;
    /*
     * Mark the stacks for &main and the current co-expression.
     */
-#ifdef MultiThread
-   markprogram(&rootpstate);
-#endif					/* MultiThread */
    markblock(&k_main);
    markblock(&k_current);
    /*
     * Mark &subject and the cached s2 and s3 strings for map.
     */
-#ifndef MultiThread
    postqual(&k_subject);
    postqual(&kywd_prog);
-#endif					/* MultiThread */
    if (Qual(maps2))                     /*  caution: the cached arguments of */
       postqual(&maps2);                 /*  map may not be strings. */
    else if (Pointer(maps2))
@@ -436,7 +362,6 @@ int region;
     * Mark the globals and the statics.
     */
 
-#ifndef MultiThread
    { register struct descrip *dp;
    for (dp = globals; dp < eglobals; dp++)
       if (Qual(*dp))
@@ -457,7 +382,6 @@ int region;
    if (is:file(lastEventWin))
       markblock(&(lastEventWin));
 #endif					/* Graphics */
-#endif					/* MultiThread */
 
    reclaim();
 
@@ -483,81 +407,15 @@ int region;
       }
    }
 
-#ifdef EventMon
-   if (!noMTevents) {
-      mmrefresh();
-      EVValD(&nulldesc, E_EndCollect);
-      }
-#endif					/* EventMon */
-
    return 1;
    }
 
-/*
- * markprogram - traverse pointers out of a program state structure
- */
-
-#ifdef MultiThread
-#define PostDescrip(d) \
-   if (Qual(d)) \
-      postqual(&(d)); \
-   else if (Pointer(d))\
-      markblock(&(d));
-
-static void markprogram(pstate)
-struct progstate *pstate;
-   {
-   struct descrip *dp;
-
-   PostDescrip(pstate->parentdesc);
-   PostDescrip(pstate->eventmask);
-   PostDescrip(pstate->opcodemask);
-   PostDescrip(pstate->eventcode);
-   PostDescrip(pstate->eventval);
-   PostDescrip(pstate->eventsource);
-
-   /* Kywd_err, &error, always an integer */
-   /* Kywd_pos, &pos, always an integer */
-   postqual(&(pstate->ksub));
-   postqual(&(pstate->Kywd_prog));
-   /* Kywd_ran, &random, always an integer */
-   /* Kywd_trc, &trace, always an integer */
-
-   /*
-    * Mark the globals and the statics.
-    */
-   for (dp = pstate->Globals; dp < pstate->Eglobals; dp++)
-      if (Qual(*dp))
-	 postqual(dp);
-      else if (Pointer(*dp))
-	 markblock(dp);
-
-   for (dp = pstate->Statics; dp < pstate->Estatics; dp++)
-      if (Qual(*dp))
-	 postqual(dp);
-      else if (Pointer(*dp))
-	 markblock(dp);
-
-   /*
-    * no marking for &x, &y, &row, &col, &interval, all integers
-    */
-#ifdef Graphics
-   PostDescrip(pstate->LastEventWin);	/* last Event() win */
-   PostDescrip(pstate->Kywd_xwin[XKey_Window]);	/* &window */
-#endif					/* Graphics */
-
-   PostDescrip(pstate->K_errorvalue);
-   PostDescrip(pstate->T_errorvalue);
-   }
-#endif					/* MultiThread */
-
 /*
  * postqual - mark a string qualifier.  Strings outside the string space
  *  are ignored.
  */
 
-static void postqual(dp)
-dptr dp;
+static void postqual(dptr dp)
    {
    char *newqual;
 
@@ -592,8 +450,7 @@ dptr dp;
  *  back-list of descriptors pointing to that block. (Phase I of garbage
  *  collection.)
  */
-static void markblock(dp)
-dptr dp;
+static void markblock(dptr dp)
    {
    register dptr dp1;
    register char *block, *endblock;
@@ -693,17 +550,6 @@ dptr dp;
       BlkType(block) = (uword)dp;
       sweep((struct b_coexpr *)block);
 
-#ifdef MultiThread
-      if (((struct b_coexpr *)block)+1 ==
-         (struct b_coexpr *)((struct b_coexpr *)block)->program){
-         /*
-          * This coexpr is an &main; traverse its roots
-          */
-         markprogram(((struct b_coexpr *)block)->program);
-         }
-#endif					/* MultiThread */
-
-#ifdef Coexpr
       /*
        * Mark the activators of this co-expression.   The activators are
        *  stored as a list of addresses, but markblock requires the address
@@ -723,7 +569,6 @@ dptr dp;
          }
       if(BlkLoc(cp->freshblk) != NULL)
          markblock(&((struct b_coexpr *)block)->freshblk);
-#endif					/* Coexpr */
       }
 
    else {
@@ -798,8 +643,7 @@ dptr dp;
  *  is just a block pointer, not a descriptor.
  */
 
-static void markptr(ptr)
-union block **ptr;
+static void markptr(union block **ptr)
    {
    register dptr dp;
    register char *block, *endblock;
@@ -934,8 +778,7 @@ union block **ptr;
  *  marking the descriptors.
  */
 
-static void sweep(ce)
-struct b_coexpr *ce;
+static void sweep(struct b_coexpr *ce)
    {
    register struct tend_desc *tp;
    register int i;
@@ -950,12 +793,9 @@ struct b_coexpr *ce;
 	    }
          }
       }
-#if !COMPILER
    sweep_stk(ce);
-#endif					/* !COMPILER */
    }
 
-#if !COMPILER
 /*
  * sweep_stk - sweep the stack, marking all descriptors there.  Method
  *  is to start at a known point, specifically, the frame that the
@@ -970,8 +810,7 @@ struct b_coexpr *ce;
  *  the "if it can't be identified it's a descriptor" methodology.
  */
 
-static void sweep_stk(ce)
-struct b_coexpr *ce;
+static void sweep_stk(struct b_coexpr *ce)
    {
    register word *s_sp;
    register struct pf_marker *fp;
@@ -992,19 +831,6 @@ struct b_coexpr *ce;
    s_sp =  ce->es_sp;
    nargs = 0;                           /* Nargs counter is 0 initially. */
 
-#ifdef MultiThread
-   if (fp == 0) {
-      if (is:list(* (dptr) (s_sp - 1))) {
-	 /*
-	  * this is the argument list of an un-started task
-	  */
-         if (Pointer(*((dptr)(&s_sp[-1])))) {
-            markblock((dptr)&s_sp[-1]);
-	    }
-	 }
-      }
-#endif					/* MultiThread */
-
    while ((fp != 0 || nargs)) {         /* Keep going until current fp is
                                             0 and no arguments are left. */
       if (s_sp == (word *)fp + Vwsizeof(*pfp) - 1) {
@@ -1071,7 +897,6 @@ struct b_coexpr *ce;
          }
       }
    }
-#endif					/* !COMPILER */
 
 /*
  * reclaim - reclaim space in the allocated memory regions. The marking
@@ -1118,11 +943,7 @@ static void cofree()
     * Reset the type for &main.
     */
 
-#ifdef MultiThread
-   rootpstate.Mainhead->title = T_Coexpr;
-#else					/* MultiThread */
    BlkLoc(k_main)->coexpr.title = T_Coexpr;
-#endif					/* MultiThread */
 
    /*
     * The co-expression blocks are linked together through their
@@ -1145,9 +966,7 @@ static void cofree()
             abp = abp->astk_nxt;
             free((pointer)xabp);
             }
-         #ifdef CoClean
-	    coclean(xep->cstate);
-         #endif				/* CoClean */
+	 coclean(xep->cstate);
          free((pointer)xep);
          }
       else {
@@ -1164,8 +983,7 @@ static void cofree()
  *  descriptors rather than pointers to them.
  */
 
-static void scollect(extra)
-word extra;
+static void scollect(word extra)
    {
    register char *source, *dest;
    register dptr *qptr;
@@ -1230,8 +1048,7 @@ word extra;
  * qlcmp - compare the location fields of two string qualifiers for qsort.
  */
 
-static int qlcmp(q1,q2)
-dptr *q1, *q2;
+static int qlcmp(dptr *q1, dptr *q2)
    {
    return (int)(DiffPtrs(StrLoc(**q1),StrLoc(**q2)));
    }
@@ -1242,8 +1059,7 @@ dptr *q1, *q2;
  *  collection.)
  */
 
-static void adjust(source,dest)
-char *source, *dest;
+static void adjust(char *source, char *dest)
    {
    register union block **nxtptr, **tptr;
 
@@ -1277,8 +1093,7 @@ char *source, *dest;
  *  collection.)
  */
 
-static void compact(source)
-char *source;
+static void compact(char *source)
    {
    register char *dest;
    register word size;
@@ -1323,9 +1138,7 @@ char *source;
  * be fairly large.)
  */
 
-static void mvc(n, src, dest)
-uword n;
-register char *src, *dest;
+static void mvc(uword n, char *src, char *dest)
    {
    register char *srcend, *destend;        /* end of data areas */
    word copy_size;                  /* of size copy_size */
@@ -1392,68 +1205,3 @@ register char *src, *dest;
     *  Note that src == dest implies no action
     */
    }
-
-#ifdef DeBugIconx
-/*
- * descr - dump a descriptor.  Used only for debugging.
- */
-
-void descr(dp)
-dptr dp;
-   {
-   int i;
-
-   fprintf(stderr,"%08lx: ",(long)dp);
-   if (Qual(*dp))
-      fprintf(stderr,"%15s","qualifier");
-
-   else if (Var(*dp))
-      fprintf(stderr,"%15s","variable");
-   else {
-      i =  Type(*dp);
-      switch (i) {
-         case T_Null:
-            fprintf(stderr,"%15s","null");
-            break;
-         case T_Integer:
-            fprintf(stderr,"%15s","integer");
-            break;
-         default:
-            fprintf(stderr,"%15s",blkname[i]);
-         }
-      }
-   fprintf(stderr," %08lx %08lx\n",(long)dp->dword,(long)IntVal(*dp));
-   }
-
-/*
- * blkdump - dump the allocated block region.  Used only for debugging.
- *   NOTE:  Not adapted for multiple regions.
- */
-
-void blkdump()
-   {
-   register char *blk;
-   register word type, size, fdesc;
-   register dptr ndesc;
-
-   fprintf(stderr,
-      "\nDump of allocated block region.  base:%08lx free:%08lx max:%08lx\n",
-         (long)blkbase,(long)blkfree,(long)blkend);
-   fprintf(stderr,"  loc     type              size  contents\n");
-
-   for (blk = blkbase; blk < blkfree; blk += BlkSize(blk)) {
-      type = BlkType(blk);
-      size = BlkSize(blk);
-      fprintf(stderr," %08lx   %15s   %4ld\n",(long)blk,blkname[type],
-         (long)size);
-      if ((fdesc = firstd[type]) > 0)
-         for (ndesc = (dptr)(blk + fdesc);
-               ndesc < (dptr)(blk + size); ndesc++) {
-            fprintf(stderr,"                                 ");
-            descr(ndesc);
-            }
-      fprintf(stderr,"\n");
-      }
-   fprintf(stderr,"end of block region.\n");
-   }
-#endif					/* DeBugIconx */
