@@ -11,18 +11,14 @@
 /*
  * Prototypes.
  */
-
-static void	listimage
-   (FILE *f,struct b_list *lp, int noimage);
-static void	printimage	(FILE *f,int c,int q);
-static char *	csname		(dptr dp);
-
+static void listimage(FILE *f, struct b_list *lp, int noimage);
+static void printimage(FILE *f, int c, int q);
+static char *csname(dptr dp);
 
 /*
  * eq - compare two Icon strings for equality
  */
-int eq(d1, d2)
-dptr d1, d2;
+int eq(dptr d1, dptr d2)
 {
 	char *s1, *s2;
 	int i;
@@ -42,25 +38,13 @@ dptr d1, d2;
  *  of the variable (Succeeded for keywords), or Failed if the variable
  *  does not exist.
  */
-int getvar(s,vp)
-   char *s;
-   dptr vp;
+int getvar(char *s, dptr vp)
    {
    register dptr dp;
    register dptr np;
    register int i;
    struct b_proc *bp;
-#if COMPILER
-   struct descrip sdp;
-
-   if (!debug_info)
-      fatalerr(402,NULL);
-
-   StrLoc(sdp) = s;
-   StrLen(sdp) = strlen(s);
-#else					/* COMPILER */
    struct pf_marker *fp = pfp;
-#endif					/* COMPILER */
 
    /*
     * Is it a keyword that's a variable?
@@ -97,15 +81,6 @@ int getvar(s,vp)
          VarLoc(*vp) = &kywd_trc;
          return Succeeded;
          }
-
-#ifdef FncTrace
-      else if (strcmp(s,"&ftrace") == 0) {
-         vp->dword = D_Kywdint;
-         VarLoc(*vp) = &kywd_ftrc;
-         return Succeeded;
-         }
-#endif					/* FncTrace */
-
       else if (strcmp(s,"&dump") == 0) {
          vp->dword = D_Kywdint;
          VarLoc(*vp) = &kywd_dmp;
@@ -119,24 +94,6 @@ int getvar(s,vp)
          }
 #endif					/* Graphics */
 
-#ifdef MultiThread
-      else if (strcmp(s,"&eventvalue") == 0) {
-         vp->dword = D_Var;
-         VarLoc(*vp) = (dptr)&(curpstate->eventval);
-         return Succeeded;
-         }
-      else if (strcmp(s,"&eventsource") == 0) {
-         vp->dword = D_Var;
-         VarLoc(*vp) = (dptr)&(curpstate->eventsource);
-         return Succeeded;
-         }
-      else if (strcmp(s,"&eventcode") == 0) {
-         vp->dword = D_Var;
-         VarLoc(*vp) = (dptr)&(curpstate->eventcode);
-         return Succeeded;
-         }
-#endif					/* MultiThread */
-
       else return Failed;
       }
 
@@ -149,53 +106,31 @@ int getvar(s,vp)
     *  If no such variable exits, it fails.
     */
 
-#if !COMPILER
    /*
     *  If no procedure has been called (as can happen with icon_call(),
     *  dont' try to find local identifier.
     */
    if (pfp == NULL)
       goto glbvars;
-#endif					/* !COMPILER */
 
    dp = glbl_argp;
-#if COMPILER
-   bp = PFDebug(*pfp)->proc;  /* get address of procedure block */
-#else					/* COMPILER */
    bp = (struct b_proc *)BlkLoc(*dp);	/* get address of procedure block */
-#endif					/* COMPILER */
 
    np = bp->lnames;		/* Check the formal parameter names. */
 
    for (i = abs((int)bp->nparam); i > 0; i--) {
-#if COMPILER
-      if (eq(&sdp, np) == 1) {
-#else					/* COMPILER */
       dp++;
       if (strcmp(s,StrLoc(*np)) == 0) {
-#endif					/* COMPILER */
          vp->dword = D_Var;
          VarLoc(*vp) = (dptr)dp;
          return ParamName;
          }
       np++;
-#if COMPILER
-      dp++;
-#endif					/* COMPILER */
       }
-
-#if COMPILER
-   dp = &pfp->tend.d[0];
-#else					/* COMPILER */
    dp = &fp->pf_locals[0];
-#endif					/* COMPILER */
 
    for (i = (int)bp->ndynam; i > 0; i--) { /* Check the local dynamic names. */
-#if COMPILER
-         if (eq(&sdp, np)) {
-#else					/* COMPILER */
 	 if (strcmp(s,StrLoc(*np)) == 0) {
-#endif					/* COMPILER */
             vp->dword = D_Var;
             VarLoc(*vp) = (dptr)dp;
             return LocalName;
@@ -206,11 +141,7 @@ int getvar(s,vp)
 
    dp = &statics[bp->fstatic]; /* Check the local static names. */
    for (i = (int)bp->nstatic; i > 0; i--) {
-#if COMPILER
-         if (eq(&sdp, np)) {
-#else					/* COMPILER */
          if (strcmp(s,StrLoc(*np)) == 0) {
-#endif					/* COMPILER */
             vp->dword = D_Var;
             VarLoc(*vp) = (dptr)dp;
             return StaticName;
@@ -219,15 +150,6 @@ int getvar(s,vp)
          dp++;
          }
 
-#if COMPILER
-   for (i = 0; i < n_globals; ++i) {
-      if (eq(&sdp, &gnames[i])) {
-         vp->dword = D_Var;
-         VarLoc(*vp) = (dptr)&globals[i];
-         return GlobalName;
-         }
-      }
-#else					/* COMPILER */
 glbvars:
    dp = globals;	/* Check the global variable names. */
    np = gnames;
@@ -240,7 +162,6 @@ glbvars:
       np++;
       dp++;
       }
-#endif					/* COMPILER */
    return Failed;
    }
 
@@ -248,8 +169,7 @@ glbvars:
  * hash - compute hash value of arbitrary object for table and set accessing.
  */
 
-uword hash(dp)
-dptr dp;
+uword hash(dptr dp)
    {
    register char *s;
    register uword i;
@@ -288,7 +208,6 @@ dptr dp;
             i = (13255 * (uword)IntVal(*dp)) >> 10;
             break;
 
-#ifdef LargeInts
          /*
           * The hash value of a bignum is based on its length and its
           *  most and least significant digits.
@@ -301,7 +220,6 @@ dptr dp;
 		(b->digits[b->msd] << 8) ^ b->digits[b->lsd];
 	    }
 	    break;
-#endif					/* LargeInts */
 
          /*
           * The hash value of a real number is itself times a constant,
@@ -376,10 +294,7 @@ dptr dp;
  *  fields of records will not be imaged.
  */
 
-void outimage(f, dp, noimage)
-FILE *f;
-dptr dp;
-int noimage;
+void outimage(FILE *f, dptr dp, int noimage)
    {
    register word i, j;
    register char *s;
@@ -412,15 +327,10 @@ int noimage;
          fprintf(f, "&null");
 
       integer:
-
-#ifdef LargeInts
          if (Type(*dp) == T_Lrgint)
             bigprint(f, dp);
          else
             fprintf(f, "%ld", (long)IntVal(*dp));
-#else					/* LargeInts */
-         fprintf(f, "%ld", (long)IntVal(*dp));
-#endif					/* LargeInts */
 
       real: {
          char s[30];
@@ -436,7 +346,7 @@ int noimage;
 	  * Check for a predefined cset; use keyword name if found.
 	  */
 	 if ((csn = csname(dp)) != NULL) {
-	    fprintf(f, csn);
+	    fprintf(f, "%s", csn);
 	    return;
 	    }
          /*
@@ -628,12 +538,6 @@ int noimage;
             fprintf(f, "&random = ");
          else if (VarLoc(*dp) == &kywd_trc)
             fprintf(f, "&trace = ");
-
-#ifdef FncTrace
-         else if (VarLoc(*dp) == &kywd_ftrc)
-            fprintf(f, "&ftrace = ");
-#endif					/* FncTrace */
-
          else if (VarLoc(*dp) == &kywd_dmp)
             fprintf(f, "&dump = ");
          else if (VarLoc(*dp) == &kywd_err)
@@ -642,14 +546,6 @@ int noimage;
          }
 
       kywdevent: {
-#ifdef MultiThread
-         if (VarLoc(*dp) == &curpstate->eventsource)
-            fprintf(f, "&eventsource = ");
-         else if (VarLoc(*dp) == &curpstate->eventcode)
-            fprintf(f, "&eventcode = ");
-         else if (VarLoc(*dp) == &curpstate->eventval)
-            fprintf(f, "&eventval = ");
-#endif					/* MultiThread */
          outimage(f, VarLoc(*dp), noimage);
          }
 
@@ -682,8 +578,13 @@ int noimage;
             outimage(f, dp, noimage);
             putc(')', f);
             }
-         else if (Type(*dp) == T_External)
-            fprintf(f, "external(%d)",((struct b_external *)BlkLoc(*dp))->blksize);
+         else if (Type(*dp) == T_External) {
+            q = callextfunc(&extlimage, dp, NULL); /* get image as a string */
+            i = StrLen(q);
+            s = StrLoc(q);
+            while (i-- > 0)
+               putc(*s++, f);
+            }
          else if (Type(*dp) <= MaxType)
             fprintf(f, "%s", blkname[Type(*dp)]);
          else
@@ -697,9 +598,7 @@ int noimage;
  *  if c is unprintable, '\', or equal to q.
  */
 
-static void printimage(f, c, q)
-FILE *f;
-int c, q;
+static void printimage(FILE *f, int c, int q)
    {
    if (printable(c)) {
       /*
@@ -764,10 +663,7 @@ int c, q;
  * listimage - print an image of a list.
  */
 
-static void listimage(f, lp, noimage)
-FILE *f;
-struct b_list *lp;
-int noimage;
+static void listimage(FILE *f, struct b_list *lp, int noimage)
    {
    register word i, j;
    register struct b_lelem *bp;
@@ -822,42 +718,34 @@ int noimage;
  *  Returns a pointer to the item matching "key", or NULL if none.
  *  Based on Bentley, CACM 28,7 (July, 1985), p. 676.
  */
+char *qsearch(char *key, char *base, int nel, int width,
+   int (*compar)(void*, void*))
+   {
+   int l, u, m, r;
+   char * a;
 
-char * qsearch (key, base, nel, width, compar)
-char * key;
-char * base;
-int nel, width;
-int (*compar)();
-{
-    int l, u, m, r;
-    char * a;
-
-    l = 0;
-    u = nel - 1;
-    while (l <= u) {
-	m = (l + u) / 2;
-	a = (char *) ((char *) base + width * m);
-	r = compar (a, key);
-	if (r < 0)
-	    l = m + 1;
-	else if (r > 0)
-	    u = m - 1;
-	else
-	    return a;
-    }
-    return 0;
-}
+   l = 0;
+   u = nel - 1;
+   while (l <= u) {
+      m = (l + u) / 2;
+      a = (char *) ((char *) base + width * m);
+      r = compar (a, key);
+      if (r < 0)
+         l = m + 1;
+      else if (r > 0)
+         u = m - 1;
+      else
+         return a;
+      }
+   return 0;
+   }
 
-#if !COMPILER
 /*
  * qtos - convert a qualified string named by *dp to a C-style string.
  *  Put the C-style string in sbuf if it will fit, otherwise put it
  *  in the string region.
  */
-
-int qtos(dp, sbuf)
-dptr dp;
-char *sbuf;
+int qtos(dptr dp, char *sbuf)
    {
    register word slen;
    register char *c, *s;
@@ -883,22 +771,15 @@ char *sbuf;
       }
    return Succeeded;
    }
-#endif					/* !COMPILER */
 
-#ifdef Coexpr
 /*
  * pushact - push actvtr on the activator stack of ce
  */
-int pushact(ce, actvtr)
-struct b_coexpr *ce, *actvtr;
+int pushact(struct b_coexpr *ce, struct b_coexpr *actvtr)
 {
    struct astkblk *abp = ce->es_actstk, *nabp;
    struct actrec *arp;
 
-#ifdef MultiThread
-   abp->arec[0].activator = actvtr;
-#else					/* MultiThread */
-
    /*
     * If the last activator is the same as this one, just increment
     *  its count.
@@ -924,29 +805,19 @@ struct b_coexpr *ce, *actvtr;
    arp->acount = 1;
    arp->activator = actvtr;
    ce->es_actstk = abp;
-#endif					/* MultiThread */
    return Succeeded;
 }
-#endif					/* Coexpr */
 
 /*
  * popact - pop the most recent activator from the activator stack of ce
  *  and return it.
  */
-struct b_coexpr *popact(ce)
-struct b_coexpr *ce;
+struct b_coexpr *popact(struct b_coexpr *ce)
 {
-
-#ifdef Coexpr
-
    struct astkblk *abp = ce->es_actstk, *oabp;
    struct actrec *arp;
    struct b_coexpr *actvtr;
 
-#ifdef MultiThread
-   return abp->arec[0].activator;
-#else					/* MultiThread */
-
    /*
     * If the current stack block is empty, pop it.
     */
@@ -971,90 +842,38 @@ struct b_coexpr *ce;
 
    ce->es_actstk = abp;
    return actvtr;
-#endif					/* MultiThread */
-
-#else					/* Coexpr */
-    syserr("popact() called, but co-expressions not implemented");
-#endif					/* Coexpr */
-
 }
 
-#ifdef Coexpr
 /*
  * topact - return the most recent activator of ce.
  */
-struct b_coexpr *topact(ce)
-struct b_coexpr *ce;
+struct b_coexpr *topact(struct b_coexpr *ce)
 {
    struct astkblk *abp = ce->es_actstk;
 
-#ifdef MultiThread
-   return abp->arec[0].activator;
-#else					/* MultiThread */
    if (abp->nactivators == 0)
       abp = abp->astk_nxt;
    return abp->arec[abp->nactivators-1].activator;
-#endif					/* MultiThread */
 }
 
-#ifdef DeBugIconx
-/*
- * dumpact - dump an activator stack
- */
-void dumpact(ce)
-struct b_coexpr *ce;
-{
-   struct astkblk *abp = ce->es_actstk;
-   struct actrec *arp;
-   int i;
-
-   if (abp)
-      fprintf(stderr, "Ce %ld ", (long)ce->id);
-   while (abp) {
-      fprintf(stderr, "--- Activation stack block (%x) --- nact = %d\n",
-         abp, abp->nactivators);
-      for (i = abp->nactivators; i >= 1; i--) {
-         arp = &abp->arec[i-1];
-         /*for (j = 1; j <= arp->acount; j++)*/
-         fprintf(stderr, "co-expression_%ld(%d)\n", (long)(arp->activator->id),
-            arp->acount);
-         }
-      abp = abp->astk_nxt;
-      }
-}
-#endif					/* DeBugIconx */
-#endif					/* Coexpr */
-
-#if !COMPILER
 /*
  * findline - find the source line number associated with the ipc
  */
-#ifdef SrcColumnInfo
-int findline(ipc)
-word *ipc;
+int findline(word *ipc)
 {
   return findloc(ipc) & 65535;
 }
-int findcol(ipc)
-word *ipc;
+int findcol(word *ipc)
 {
   return findloc(ipc) >> 16;
 }
 
-int findloc(ipc)
-#else					/* SrcColumnInfo */
-int findline(ipc)
-#endif					/* SrcColumnInfo */
-word *ipc;
+int findloc(word *ipc)
 {
    uword ipc_offset;
    uword size;
    struct ipc_line *base;
-
-#ifndef MultiThread
    extern struct ipc_line *ilines, *elines;
-#endif					/* MultiThread */
-
    static int two = 2;	/* some compilers generate bad code for division
 			   by a constant that is a power of two ... */
 
@@ -1079,16 +898,11 @@ word *ipc;
 /*
  * findipc - find the first ipc associated with a source-code line number.
  */
-int findipc(line)
-int line;
+int findipc(int line)
 {
    uword size;
    struct ipc_line *base;
-
-#ifndef MultiThread
    extern struct ipc_line *ilines, *elines;
-#endif					/* MultiThread */
-
    static int two = 2;	/* some compilers generate bad code for division
 			   by a constant that is a power of two ... */
 
@@ -1108,15 +922,11 @@ int line;
 /*
  * findfile - find source file name associated with the ipc
  */
-char *findfile(ipc)
-word *ipc;
+char *findfile(word *ipc)
 {
    uword ipc_offset;
    struct ipc_fname *p;
-
-#ifndef MultiThread
    extern struct ipc_fname *filenms, *efilenms;
-#endif					/* MultiThread */
 
    if (!InRange(code,ipc,ecode))
       return "?";
@@ -1130,7 +940,6 @@ word *ipc;
    /*NOTREACHED*/
    return 0;  /* avoid gcc warning */
 }
-#endif					/* !COMPILER */
 
 /*
  * doimage(c,q) - allocate character c in string space, with escape
@@ -1138,8 +947,7 @@ word *ipc;
  *  Returns number of characters allocated.
  */
 
-int doimage(c, q)
-int c, q;
+int doimage(int c, int q)
    {
    static char cbuf[5];
 
@@ -1209,8 +1017,7 @@ int c, q;
  * getimage(dp1,dp2) - return string image of object dp1 in dp2.
  */
 
-int getimage(dp1,dp2)
-dptr dp1, dp2;
+int getimage(dptr dp1, dptr dp2)
    {
    register word len, outlen, rnlen;
    int i;
@@ -1249,7 +1056,6 @@ dptr dp1, dp2;
          }
 
       integer: {
-#ifdef LargeInts
          if (Type(source) == T_Lrgint) {
             word slen;
             word dlen;
@@ -1271,9 +1077,6 @@ dptr dp1, dp2;
 	    }
          else
             cnv: string(source, *dp2);
-#else					/* LargeInts */
-         cnv:string(source, *dp2);
-#endif					/* LargeInts */
 	 }
 
       real: {
@@ -1472,16 +1275,9 @@ dptr dp1, dp2;
          }
 
       default:
-        if (Type(*dp1) == T_External) {
-           /*
-            * For now, just produce "external(n)".
-            */
-           sprintf(sbuf, "external(%ld)", (long)BlkLoc(*dp1)->externl.blksize);
-           len = strlen(sbuf);
-           Protect(t = alcstr(sbuf, len), return Error);
-           StrLoc(*dp2) = t;
-           StrLen(*dp2) = len;
-           }
+         if (Type(*dp1) == T_External) {
+            *dp2 = callextfunc(&extlimage, dp1, NULL);
+            }
          else {
 	    ReturnErrVal(123, source, Error);
             }
@@ -1492,8 +1288,7 @@ dptr dp1, dp2;
 /*
  * csname(dp) -- return the name of a predefined cset matching dp.
  */
-static char *csname(dp)
-dptr dp;
+static char *csname(dptr dp)
    {
    register int n;
 
@@ -1532,8 +1327,7 @@ dptr dp;
 /*
  * cssize(dp) - calculate cset size, store it, and return it
  */
-int cssize(dp)
-dptr dp;
+int cssize(dptr dp)
 {
    register int i, n;
    register unsigned int w, *wp;
@@ -1552,9 +1346,7 @@ dptr dp;
 /*
  * printable(c) -- is c a "printable" character?
  */
-
-int printable(c)
-int c;
+int printable(int c)
    {
    return (isascii(c) && isprint(c));
    }
@@ -1569,8 +1361,7 @@ extern int over_flow;
 /*
  * add - integer addition with overflow checking
  */
-word add(a, b)
-word a, b;
+word add(word a, word b)
 {
    if ((a ^ b) >= 0 && (a >= 0 ? b > MaxLong - a : b < MinLong - a)) {
       over_flow = 1;
@@ -1585,8 +1376,7 @@ word a, b;
 /* 
  * sub - integer subtraction with overflow checking
  */
-word sub(a, b)
-word a, b;
+word sub(word a, word b)
 {
    if ((a ^ b) < 0 && (a >= 0 ? b < a - MaxLong : b > a - MinLong)) {
       over_flow = 1;
@@ -1601,8 +1391,7 @@ word a, b;
 /*
  * mul - integer multiplication with overflow checking
  */
-word mul(a, b)
-word a, b;
+word mul(word a, word b)
 {
    if (b != 0) {
       if ((a ^ b) >= 0) {
@@ -1624,8 +1413,7 @@ word a, b;
 /*
  * mod3 - integer modulo with overflow checking (always rounds to 0)
  */
-word mod3(a, b)
-word a, b;
+word mod3(word a, word b)
 {
    word retval;
 
@@ -1658,8 +1446,7 @@ word a, b;
 /*
  * div3 - integer divide with overflow checking (always rounds to 0)
  */
-word div3(a, b)
-word a, b;
+word div3(word a, word b)
 {
    if ( ( b == 0 ) ||	/* Not really an overflow, but definitely an error */
         ( b == -1 && a == MinLong ) ) {
@@ -1674,8 +1461,7 @@ word a, b;
 /*
  * neg - integer negation with overflow checking
  */
-word neg(a)
-word a;
+word neg(word a)
 {
    if (a == MinLong) {
       over_flow = 1;
@@ -1685,109 +1471,12 @@ word a;
    return -a;
 }
 
-#if COMPILER
-/*
- * sig_rsm - standard success continuation that just signals resumption.
- */
-
-int sig_rsm()
-   {
-   return A_Resume;
-   }
-
-/*
- * cmd_line - convert command line arguments into a list of strings.
- */
-void cmd_line(argc, argv, rslt)
-int argc;
-char **argv;
-dptr rslt;
-   {
-   tended struct b_list *hp;
-   register word i;
-   register struct b_lelem *bp;  /* need not be tended */
-
-   /*
-    * Skip the program name.
-    */
-   --argc;
-   ++argv;
-
-   /*
-    * Allocate the list and a list block.
-    */
-   Protect(hp = alclist(argc), fatalerr(0,NULL));
-   Protect(bp = alclstb(argc, (word)0, argc), fatalerr(0,NULL));
-
-   /*
-    * Make the list block just allocated into the first and last blocks
-    *  for the list.
-    */
-   hp->listhead = hp->listtail = (union block *)bp;
-#ifdef ListFix
-   bp->listprev = bp->listnext = (union block *)hp;
-#endif					/* ListFix */
-
-   /*
-    * Copy the arguments into the list
-    */
-   for (i = 0; i < argc; ++i) {
-      StrLen(bp->lslots[i]) = strlen(argv[i]);
-      StrLoc(bp->lslots[i]) = argv[i];
-      }
-
-   rslt->dword = D_List;
-   rslt->vword.bptr = (union block *) hp;
-   }
-
-/*
- * varargs - construct list for use in procedures with variable length
- *  argument list.
- */
-void varargs(argp, nargs, rslt)
-dptr argp;
-int nargs;
-dptr rslt;
-   {
-   tended struct b_list *hp;
-   register word i;
-   register struct b_lelem *bp;  /* need not be tended */
-
-   /*
-    * Allocate the list and a list block.
-    */
-   Protect(hp = alclist(nargs), fatalerr(0,NULL));
-   Protect(bp = alclstb(nargs, (word)0, nargs), fatalerr(0,NULL));
-
-   /*
-    * Make the list block just allocated into the first and last blocks
-    *  for the list.
-    */
-   hp->listhead = hp->listtail = (union block *)bp;
-#ifdef ListFix
-   bp->listprev = bp->listnext = (union block *)hp;
-#endif					/* ListFix */
-
-   /*
-    * Copy the arguments into the list
-    */
-   for (i = 0; i < nargs; i++)
-      deref(&argp[i], &bp->lslots[i]);
-
-   rslt->dword = D_List;
-   rslt->vword.bptr = (union block *) hp;
-   }
-#endif					/* COMPILER */
-
 /*
  * retderef - Dereference local variables and substrings of local
  *  string-valued variables. This is used for return, suspend, and
  *  transmitting values across co-expression context switches.
  */
-void retderef(valp, low, high)
-dptr valp;
-word *low;
-word *high;
+void retderef(dptr valp, word *low, word *high)
    {
    struct b_tvsubs *tvb;
    word *loc;
