@@ -5,6 +5,9 @@
  * Resources are allocated through a layer of internal management
  * routines in order to handle aliasing and resource sharing.
  */
+
+#passthru #pragma GCC diagnostic ignored "-Wunused-variable"
+
 #ifdef Graphics
 
 /*
@@ -35,8 +38,7 @@ wbp alc_wbinding()
 /*
  * free a window binding.
  */
-void free_binding(w)
-wbp w;
+void free_binding(wbp w)
    {
    w->refcount--;
    if(w->refcount == 0) {
